@@ -1,8 +1,8 @@
 //===========================================================================
-// @(#) $Name$
-// @(#) $Id: DwmBZ2IO.cc 9111 2017-04-14 22:22:47Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/src/DwmBZ2IO.cc 11088 $
+// @(#) $Id: DwmBZ2IO.cc 11088 2020-09-07 15:56:24Z dwm $
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 2004-2007
+//  Copyright (c) Daniel W. McRobb 2004-2007, 2020
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -34,98 +34,31 @@
 //  PATENT, TRADEMARK OR OTHER RIGHTS.
 //===========================================================================
 
-extern "C" {
-  #include <sys/types.h>
-  #ifdef __FreeBSD__
-    #include <sys/endian.h>
-  #endif
-  #include <unistd.h>
-  #include <stdlib.h>
-  #include <netinet/in.h>
-  #include <rpc/rpc.h>
-  #include <rpc/xdr.h>
+//---------------------------------------------------------------------------
+//!  \file DwmBZ2IO.cc
+//!  \author Daniel W. McRobb
+//!  \brief Dwm::BZ2IO class implementation
+//---------------------------------------------------------------------------
 
-  #ifdef __OpenBSD__
-    #define be64toh  betoh64
-  #endif
+extern "C" {
+#if (defined(__unix__) || defined(unix) || defined(__unix)) || (defined(__APPLE__))
+  #include <sys/types.h>
+  #include <unistd.h>
+#endif
 }
 
 #include <cassert>
+#include <cstdlib>
 
 #include "DwmBZ2IO.hh"
 #include "DwmSvnTag.hh"
 #include "DwmPortability.hh"
+#include "DwmXDRUtils.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/src/DwmBZ2IO.cc 9111 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/src/DwmBZ2IO.cc 11088 $");
 
 namespace Dwm {
 
-  //--------------------------------------------------------------------------
-  //!  
-  //--------------------------------------------------------------------------
-  static uint32_t XdrEncode(float val, char **buf)
-  {
-    float value = val;
-    XDR   xdrs;
-    if (*buf)
-      free(*buf);
-    *buf = (char *)malloc(4);
-    xdrmem_create(&xdrs,*buf,4,XDR_ENCODE);
-    xdr_float(&xdrs,&value);
-    xdr_destroy((&xdrs));
-    return(4);
-  }
-  
-  //--------------------------------------------------------------------------
-  //!  
-  //--------------------------------------------------------------------------
-  static uint32_t XdrEncode(double val, char **buf)
-  {
-    double  value = val;
-    XDR   xdrs;
-    if (*buf)
-      free(*buf);
-    *buf = (char *)malloc(8);
-    xdrmem_create(&xdrs,*buf,8,XDR_ENCODE);
-    xdr_double(&xdrs,&value);
-    xdr_destroy((&xdrs));
-    return(8);
-  }
-  
-  //--------------------------------------------------------------------------
-  //!  
-  //--------------------------------------------------------------------------
-  static void XdrDecode(char *buf, float & val)
-  {
-    assert(buf);
-
-    float  value;
-    XDR    xdrs;
-    xdrmem_create(&xdrs,buf,4,XDR_DECODE);
-    xdr_float(&xdrs,&value);
-    val = value;
-    xdr_destroy((&xdrs));
-
-    return;
-  }
-
-  //--------------------------------------------------------------------------
-  //!  
-  //--------------------------------------------------------------------------
-  static void XdrDecode(char *buf, double & val)
-  {
-    assert(buf);
-
-    double  value;
-    XDR     xdrs;
-    xdrmem_create(&xdrs,buf,8,XDR_DECODE);
-    xdr_double(&xdrs,&value);
-    val = value;
-    xdr_destroy((&xdrs));
-
-    return;
-  }
-  
   //------------------------------------------------------------------------
   //!  
   //------------------------------------------------------------------------
@@ -155,7 +88,7 @@ namespace Dwm {
   {
     int  rc = -1;
     if (bzf) {
-      int16_t v = htons(val);
+      int16_t v = htobe16(val);
       rc = BZ2_bzwrite(bzf,(void *)&v,sizeof(v));
     }
     return(rc);
@@ -168,7 +101,7 @@ namespace Dwm {
   {
     int  rc = -1;
     if (bzf) {
-      uint16_t v = htons(val);
+      uint16_t v = htobe16(val);
       rc = BZ2_bzwrite(bzf,(void *)&v,sizeof(v));
     }
     return(rc);
@@ -181,7 +114,7 @@ namespace Dwm {
   {
     int  rc = -1;
     if (bzf) {
-      int32_t v = htonl(val);
+      int32_t v = htobe32(val);
       rc = BZ2_bzwrite(bzf,(void *)&v,sizeof(v));
     }
     return(rc);
@@ -194,7 +127,7 @@ namespace Dwm {
   {
     int  rc = -1;
     if (bzf) {
-      uint32_t v = htonl(val);
+      uint32_t v = htobe32(val);
       rc = BZ2_bzwrite(bzf,(void *)&v,sizeof(v));
     }
     return(rc);
@@ -229,44 +162,66 @@ namespace Dwm {
     }
     return(rc);
   }
+
+#if (defined(__unix__) || defined(unix) || defined(__unix)) || (defined(__APPLE__))
+
+  //--------------------------------------------------------------------------
+  //!  
+  //--------------------------------------------------------------------------
+  int BZ2IO::BZWrite(BZFILE *bzf, float val)
+  {
+    int  rc = -1;
+    if (bzf) {
+      char     *buf = 0;
+      uint32_t  xe = XDRUtils::Encode(val, &buf);
+      rc = BZ2_bzwrite(bzf, buf, xe);
+      free(buf);
+      if (rc < 4) {
+        rc = -1;
+      }
+    }
+    return rc;
+  }
+
+  //--------------------------------------------------------------------------
+  //!  
+  //--------------------------------------------------------------------------
+  int BZ2IO::BZWrite(BZFILE *bzf, const double & val)
+  {
+    int  rc = -1;
+    if (bzf) {
+      char  *buf = 0;
+      uint32_t  xe = XDRUtils::Encode(val, &buf);
+      rc = BZ2_bzwrite(bzf, buf, xe);
+      if (rc < 8) {
+        rc = -1;
+      }
+    }
+    return rc;
+  }
+
+#elif (defined(_WIN32) || defined(_WIN64))
   
   //--------------------------------------------------------------------------
   //!  
   //--------------------------------------------------------------------------
   int BZ2IO::BZWrite(BZFILE *bzf, float val)
   {
-    if (! bzf)
-      return(-1);
-    
-    char     *buf = 0;
-    uint32_t  xe = XdrEncode(val,&buf);
-    int   rc = BZ2_bzwrite(bzf,buf,xe);
-    free(buf);
-    
-    if (rc < 4)
-      rc = -1;
-
-    return(rc);
+    const uint32_t  *p = (const uint32_t *)&val;
+    return BZ2IO::Write(bzf, *p);
   }
-  
+
   //--------------------------------------------------------------------------
   //!  
   //--------------------------------------------------------------------------
   int BZ2IO::BZWrite(BZFILE *bzf, const double & val)
   {
-    if (! bzf)
-      return(-1);
-    
-    char  *buf = 0;
-    uint32_t  xe = XdrEncode(val,&buf);
-    int   rc = BZ2_bzwrite(bzf,buf,xe);
-
-    if (rc < 8)
-      rc = -1;
-
-    return(rc);
+    const uint64_t  *p = (const uint64_t *)&val;
+    return BZ2IO::Write(bzf, *p);
   }
   
+#endif
+  
   //------------------------------------------------------------------------
   //!  
   //------------------------------------------------------------------------
@@ -319,7 +274,7 @@ namespace Dwm {
       int16_t  v;
       rc = BZ2_bzread(bzf,(void *)&v,sizeof(v));
       if (rc == sizeof(v))
-        val = ntohs(v);
+        val = be16toh(v);
     }
     return(rc);
   }
@@ -334,7 +289,7 @@ namespace Dwm {
       uint16_t  v;
       rc = BZ2_bzread(bzf,(void *)&v,sizeof(v));
       if (rc == sizeof(v))
-        val = ntohs(v);
+        val = be16toh(v);
     }
     return(rc);
   }
@@ -349,7 +304,7 @@ namespace Dwm {
       int32_t  v;
       rc = BZ2_bzread(bzf,(void *)&v,sizeof(v));
       if (rc == sizeof(v))
-        val = ntohl(v);
+        val = be32toh(v);
     }
     return(rc);
   }
@@ -364,7 +319,7 @@ namespace Dwm {
       uint32_t  v;
       rc = BZ2_bzread(bzf,(void *)&v,sizeof(v));
       if (rc == sizeof(v))
-        val = ntohl(v);
+        val = be32toh(v);
     }
     return(rc);
   }
@@ -400,6 +355,8 @@ namespace Dwm {
     }
     return(rc);
   }
+
+#if (defined(__unix__) || defined(unix) || defined(__unix)) || (defined(__APPLE__))
   
   //--------------------------------------------------------------------------
   //!  
@@ -408,13 +365,16 @@ namespace Dwm {
   {
     int  rc = -1;
     if (bzf) {
-      char     buf[4];
-      int  rc = BZ2_bzread(bzf,buf,4);
+      char buf[4];
+      rc = BZ2_bzread(bzf, buf, 4);
       if (rc == 4) {
-        XdrDecode(buf,val);
+        XDRUtils::Decode(buf, val);
+      }
+      else {
+        rc = -1;
       }
     }
-    return(rc);
+    return rc;
   }
   
   //--------------------------------------------------------------------------
@@ -424,14 +384,39 @@ namespace Dwm {
   {
     int  rc = -1;
     if (bzf) {
-      char     buf[8];
-      int  rc = BZ2_bzread(bzf,buf,8);
+      char  buf[8];
+      rc = BZ2_bzread(bzf,buf,8);
       if (rc == 8) {
-        XdrDecode(buf,val);
+        XDRUtils::Decode(buf, val);
+      }
+      else {
+        rc = -1;
       }
     }
-    return(rc);
+    return rc;
   }
+
+#elif (defined(_WIN32) || defined(_WIN64))
+
+  //--------------------------------------------------------------------------
+  //!  
+  //--------------------------------------------------------------------------
+  int BZ2IO::BZRead(BZFILE *bzf, float & val)
+  {
+    uint32_t  *p = (uint32_t *)&val;
+    return BZRead(bzf, *p);
+  }
+
+  //--------------------------------------------------------------------------
+  //!  
+  //--------------------------------------------------------------------------
+  int BZ2IO::BZRead(BZFILE *bzf, double & val)
+  {
+    uint64_t  *p = (uint64_t *)&val;
+    return BZRead(bzf, *p);
+  }
+  
+#endif
   
   //------------------------------------------------------------------------
   //!  
