@@ -1,8 +1,8 @@
 //===========================================================================
-// @(#) $Name$
-// @(#) $Id: DwmGZIO.cc 9110 2017-04-14 22:22:15Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/src/DwmGZIO.cc 11096 $
+// @(#) $Id: DwmGZIO.cc 11096 2020-09-07 22:11:09Z dwm $
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 2004-2007
+//  Copyright (c) Daniel W. McRobb 2004-2007, 2020
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -34,20 +34,17 @@
 //  PATENT, TRADEMARK OR OTHER RIGHTS.
 //===========================================================================
 
+//---------------------------------------------------------------------------
+//!  \file DwmGZIO.cc
+//!  \author Daniel W. McRobb
+//!  \brief Dwm::GZIO class implementation
+//---------------------------------------------------------------------------
+
 extern "C" {
   #include <sys/types.h>
-  #ifdef __FreeBSD__
-    #include <sys/endian.h>
-  #endif
   #include <unistd.h>
   #include <stdlib.h>
   #include <netinet/in.h>
-  #include <rpc/rpc.h>
-  #include <rpc/xdr.h>
-
-  #ifdef __OpenBSD__
-    #define be64toh  betoh64
-  #endif
 }
 
 #include <cassert>
@@ -55,77 +52,12 @@ extern "C" {
 #include "DwmSvnTag.hh"
 #include "DwmGZIO.hh"
 #include "DwmPortability.hh"
+#include "DwmXDRUtils.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/src/DwmGZIO.cc 9110 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/src/DwmGZIO.cc 11096 $");
 
 namespace Dwm {
 
-  //--------------------------------------------------------------------------
-  //!  
-  //--------------------------------------------------------------------------
-  static uint32_t XdrEncode(float val, char **buf)
-  {
-    float value = val;
-    XDR   xdrs;
-    if (*buf)
-      free(*buf);
-    *buf = (char *)malloc(4);
-    xdrmem_create(&xdrs,*buf,4,XDR_ENCODE);
-    xdr_float(&xdrs,&value);
-    xdr_destroy((&xdrs));
-    return(4);
-  }
-  
-  //--------------------------------------------------------------------------
-  //!  
-  //--------------------------------------------------------------------------
-  static uint32_t XdrEncode(double val, char **buf)
-  {
-    double  value = val;
-    XDR   xdrs;
-    if (*buf)
-      free(*buf);
-    *buf = (char *)malloc(8);
-    xdrmem_create(&xdrs,*buf,8,XDR_ENCODE);
-    xdr_double(&xdrs,&value);
-    xdr_destroy((&xdrs));
-    return(8);
-  }
-  
-  //--------------------------------------------------------------------------
-  //!  
-  //--------------------------------------------------------------------------
-  static void XdrDecode(char *buf, float & val)
-  {
-    assert(buf);
-
-    float  value;
-    XDR    xdrs;
-    xdrmem_create(&xdrs,buf,4,XDR_DECODE);
-    xdr_float(&xdrs,&value);
-    val = value;
-    xdr_destroy((&xdrs));
-
-    return;
-  }
-
-  //--------------------------------------------------------------------------
-  //!  
-  //--------------------------------------------------------------------------
-  static void XdrDecode(char *buf, double & val)
-  {
-    assert(buf);
-
-    double  value;
-    XDR     xdrs;
-    xdrmem_create(&xdrs,buf,8,XDR_DECODE);
-    xdr_double(&xdrs,&value);
-    val = value;
-    xdr_destroy((&xdrs));
-
-    return;
-  }
-  
   //------------------------------------------------------------------------
   //!  
   //------------------------------------------------------------------------
@@ -155,7 +87,7 @@ namespace Dwm {
   {
     int  rc = -1;
     if (gzf) {
-      int16_t v = htons(val);
+      int16_t v = htobe16(val);
       rc = gzwrite(gzf,(void *)&v,sizeof(v));
     }
     return(rc);
@@ -168,7 +100,7 @@ namespace Dwm {
   {
     int  rc = -1;
     if (gzf) {
-      uint16_t v = htons(val);
+      uint16_t v = htobe16(val);
       rc = gzwrite(gzf,(void *)&v,sizeof(v));
     }
     return(rc);
@@ -181,7 +113,7 @@ namespace Dwm {
   {
     int  rc = -1;
     if (gzf) {
-      int32_t v = htonl(val);
+      int32_t v = htobe32(val);
       rc = gzwrite(gzf,(void *)&v,sizeof(v));
     }
     return(rc);
@@ -194,7 +126,7 @@ namespace Dwm {
   {
     int  rc = -1;
     if (gzf) {
-      uint32_t v = htonl(val);
+      uint32_t v = htobe32(val);
       rc = gzwrite(gzf,(void *)&v,sizeof(v));
     }
     return(rc);
@@ -239,7 +171,7 @@ namespace Dwm {
       return(-1);
     
     char     *buf = 0;
-    uint32_t  xe = XdrEncode(val,&buf);
+    uint32_t  xe = XDRUtils::Encode(val,&buf);
     int   rc = gzwrite(gzf,buf,xe);
     free(buf);
     
@@ -258,7 +190,7 @@ namespace Dwm {
       return(-1);
     
     char  *buf = 0;
-    uint32_t  xe = XdrEncode(val,&buf);
+    uint32_t  xe = XDRUtils::Encode(val,&buf);
     int   rc = gzwrite(gzf,buf,xe);
 
     if (rc < 8)
@@ -293,8 +225,9 @@ namespace Dwm {
   int GZIO::Read(gzFile gzf, char & c)
   {
     int  rc = -1;
-    if (gzf)
+    if (gzf) {
       rc = gzread(gzf,(void *)&c,sizeof(c));
+    }
     return(rc);
   }
   
@@ -304,8 +237,9 @@ namespace Dwm {
   int GZIO::Read(gzFile gzf, uint8_t & c)
   {
     int  rc = -1;
-    if (gzf)
+    if (gzf) {
       rc = gzread(gzf,(void *)&c,sizeof(c));
+    }
     return(rc);
   }
   
@@ -318,8 +252,9 @@ namespace Dwm {
     if (gzf) {
       int16_t  v;
       rc = gzread(gzf,(void *)&v,sizeof(v));
-      if (rc == sizeof(v))
-        val = ntohs(v);
+      if (rc == sizeof(v)) {
+        val = be16toh(v);
+      }
     }
     return(rc);
   }
@@ -333,8 +268,9 @@ namespace Dwm {
     if (gzf) {
       uint16_t  v;
       rc = gzread(gzf,(void *)&v,sizeof(v));
-      if (rc == sizeof(v))
-        val = ntohs(v);
+      if (rc == sizeof(v)) {
+        val = be16toh(v);
+      }
     }
     return(rc);
   }
@@ -348,8 +284,9 @@ namespace Dwm {
     if (gzf) {
       int32_t  v;
       rc = gzread(gzf,(void *)&v,sizeof(v));
-      if (rc == sizeof(v))
-        val = ntohl(v);
+      if (rc == sizeof(v)) {
+        val = be32toh(v);
+      }
     }
     return(rc);
   }
@@ -363,8 +300,9 @@ namespace Dwm {
     if (gzf) {
       uint32_t  v;
       rc = gzread(gzf,(void *)&v,sizeof(v));
-      if (rc == sizeof(v))
-        val = ntohl(v);
+      if (rc == sizeof(v)) {
+        val = be32toh(v);
+      }
     }
     return(rc);
   }
@@ -409,9 +347,9 @@ namespace Dwm {
     int  rc = -1;
     if (gzf) {
       char     buf[4];
-      int  rc = gzread(gzf,buf,4);
+      int  rc = gzread(gzf, buf, 4);
       if (rc == 4) {
-        XdrDecode(buf,val);
+        XDRUtils::Decode(buf, val);
       }
     }
     return(rc);
@@ -425,9 +363,9 @@ namespace Dwm {
     int  rc = -1;
     if (gzf) {
       char     buf[8];
-      int  rc = gzread(gzf,buf,8);
+      int  rc = gzread(gzf, buf, 8);
       if (rc == 8) {
-        XdrDecode(buf,val);
+        XDRUtils::Decode(buf, val);
       }
     }
     return(rc);
