@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name$
-// @(#) $Id: DwmIO.cc 10858 2020-07-27 05:19:15Z dwm $
+// @(#) $Id: DwmIO.cc 11084 2020-09-06 04:57:40Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2004-2007, 2013, 2017, 2020
 //  All rights reserved.
@@ -36,18 +36,9 @@
 
 extern "C" {
   #include <sys/types.h>
-  #ifdef __FreeBSD__
-    #include <sys/endian.h>
-  #endif
   #include <unistd.h>
   #include <stdlib.h>
-  #include <netinet/in.h>
-  #include <rpc/rpc.h>
-  #include <rpc/xdr.h>
   #include <fcntl.h>
-  #ifdef __OpenBSD__
-    #define be64toh  betoh64
-  #endif
 }
 
 #include <cassert>
@@ -56,8 +47,9 @@ extern "C" {
 #include "DwmSysLogger.hh"
 #include "DwmIO.hh"
 #include "DwmPortability.hh"
+#include "DwmXDRUtils.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/src/DwmIO.cc 10858 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/src/DwmIO.cc 11084 $");
 
 namespace Dwm {
 
@@ -96,7 +88,7 @@ namespace Dwm {
   std::ostream & IO::Write(std::ostream & os, int16_t val)
   {
     if (os) {
-      int16_t  v = htons(val);
+      int16_t  v = htobe16(val);
       os.write((caddr_t)&v,sizeof(v));
     }
     return(os);
@@ -108,7 +100,7 @@ namespace Dwm {
   std::ostream & IO::Write(std::ostream & os, uint16_t val)
   {
     if (os) {
-      uint16_t v = htons(val);
+      uint16_t v = htobe16(val);
       os.write((caddr_t)&v,sizeof(v));
     }
     return(os);
@@ -120,7 +112,7 @@ namespace Dwm {
   std::ostream & IO::Write(std::ostream & os, int32_t val)
   {
     if (os) {
-      int32_t v = htonl(val);
+      int32_t v = htobe32(val);
       os.write((caddr_t)&v,sizeof(v));
     }
     return(os);
@@ -132,7 +124,7 @@ namespace Dwm {
   std::ostream & IO::Write(std::ostream & os, uint32_t val)
   {
     if (os) {
-      uint32_t v = htonl(val);
+      uint32_t v = htobe32(val);
       os.write((caddr_t)&v,sizeof(v));
     }
     return(os);
@@ -162,38 +154,6 @@ namespace Dwm {
     return(os);
   }
 
-  //--------------------------------------------------------------------------
-  //!  
-  //--------------------------------------------------------------------------
-  static uint32_t XdrEncode(float val, char **buf)
-  {
-    float value = val;
-    XDR   xdrs;
-    if (*buf)
-      free(*buf);
-    *buf = (char *)malloc(4);
-    xdrmem_create(&xdrs,*buf,4,XDR_ENCODE);
-    xdr_float(&xdrs,&value);
-    xdr_destroy((&xdrs));
-    return(4);
-  }
-  
-  //--------------------------------------------------------------------------
-  //!  
-  //--------------------------------------------------------------------------
-  static uint32_t XdrEncode(double val, char **buf)
-  {
-    double  value = val;
-    XDR   xdrs;
-    if (*buf)
-      free(*buf);
-    *buf = (char *)malloc(8);
-    xdrmem_create(&xdrs,*buf,8,XDR_ENCODE);
-    xdr_double(&xdrs,&value);
-    xdr_destroy((&xdrs));
-    return(8);
-  }
-  
   //--------------------------------------------------------------------------
   //!  
   //--------------------------------------------------------------------------
@@ -201,8 +161,8 @@ namespace Dwm {
   {
     if (os) {
       char     *buf = 0;
-      uint32_t  rc = XdrEncode(val,&buf);
-      os.write(buf,rc);
+      uint32_t  rc = XDRUtils::Encode(val, &buf);
+      os.write(buf, rc);
       free(buf);
     }
                 
@@ -216,8 +176,8 @@ namespace Dwm {
   {
     if (os) {
       char     *buf = 0;
-      uint32_t  rc = XdrEncode(val,&buf);
-      os.write(buf,rc);
+      uint32_t  rc = XDRUtils::Encode(val, &buf);
+      os.write(buf, rc);
       free(buf);
     }
 
@@ -279,7 +239,7 @@ namespace Dwm {
     if (is) {
       int16_t  v;
       if (is.read((caddr_t)&v,sizeof(v)))
-        val = ntohs(v);
+        val = be16toh(v);
     }
     return(is);
   }
@@ -292,7 +252,7 @@ namespace Dwm {
     if (is) {
       uint16_t  v;
       if (is.read((caddr_t)&v,sizeof(v)))
-        val = ntohs(v);
+        val = be16toh(v);
     }
     return(is);
   }
@@ -305,7 +265,7 @@ namespace Dwm {
     if (is) {
       int32_t  v;
       if (is.read((caddr_t)&v,sizeof(v)))
-        val = ntohl(v);
+        val = be32toh(v);
     }
     return(is);
   }
@@ -318,7 +278,7 @@ namespace Dwm {
     if (is) {
       uint32_t  v;
       if (is.read((caddr_t)&v,sizeof(v)))
-        val = ntohl(v);
+        val = be32toh(v);
     }
     return(is);
   }
@@ -351,40 +311,6 @@ namespace Dwm {
     return(is);
   }
   
-  //--------------------------------------------------------------------------
-  //!  
-  //--------------------------------------------------------------------------
-  static void XdrDecode(char *buf, float & val)
-  {
-    assert(buf);
-
-    float  value;
-    XDR    xdrs;
-    xdrmem_create(&xdrs,buf,4,XDR_DECODE);
-    xdr_float(&xdrs,&value);
-    val = value;
-    xdr_destroy((&xdrs));
-
-    return;
-  }
-
-  //--------------------------------------------------------------------------
-  //!  
-  //--------------------------------------------------------------------------
-  static void XdrDecode(char *buf, double & val)
-  {
-    assert(buf);
-
-    double  value;
-    XDR     xdrs;
-    xdrmem_create(&xdrs,buf,8,XDR_DECODE);
-    xdr_double(&xdrs,&value);
-    val = value;
-    xdr_destroy((&xdrs));
-
-    return;
-  }
-  
   //--------------------------------------------------------------------------
   //!  
   //--------------------------------------------------------------------------
@@ -392,8 +318,9 @@ namespace Dwm {
   {
     if (is) {
       char  buf[4];
-      if (is.read(buf,4))
-        XdrDecode(buf,val);
+      if (is.read(buf, 4)) {
+        XDRUtils::Decode(buf, val);
+      }
     }
     return(is);
   }
@@ -405,8 +332,9 @@ namespace Dwm {
   {
     if (is) {
       char  buf[8];
-      if (is.read(buf,8))
-        XdrDecode(buf,val);
+      if (is.read(buf, 8)) {
+        XDRUtils::Decode(buf, val);
+      }
     }
     return(is);
   }
@@ -478,7 +406,7 @@ namespace Dwm {
   {
     ssize_t  rc = -1;
     if (fd >= 0) {
-      int16_t v = htons(val);
+      int16_t v = htobe16(val);
       rc = write(fd,(void *)&v,sizeof(v));
     }
     return(rc);
@@ -491,7 +419,7 @@ namespace Dwm {
   {
     ssize_t  rc = -1;
     if (fd >= 0) {
-      uint16_t v = htons(val);
+      uint16_t v = htobe16(val);
       rc = write(fd,(void *)&v,sizeof(v));
     }
     return(rc);
@@ -504,7 +432,7 @@ namespace Dwm {
   {
     ssize_t  rc = -1;
     if (fd >= 0) {
-      int32_t v = htonl(val);
+      int32_t v = htobe32(val);
       rc = write(fd,(void *)&v,sizeof(v));
     }
     return(rc);
@@ -517,7 +445,7 @@ namespace Dwm {
   {
     ssize_t  rc = -1;
     if (fd >= 0) {
-      uint32_t v = htonl(val);
+      uint32_t v = htobe32(val);
       rc = write(fd,(void *)&v,sizeof(v));
     }
     return(rc);
@@ -562,8 +490,8 @@ namespace Dwm {
       return(-1);
     
     char     *buf = 0;
-    uint32_t  xe = XdrEncode(val,&buf);
-    ssize_t   rc = write(fd,buf,xe);
+    uint32_t  xe = XDRUtils::Encode(val, &buf);
+    ssize_t   rc = write(fd, buf, xe);
     free(buf);
     
     if (rc < 4)
@@ -577,16 +505,16 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   ssize_t IO::Write(int fd, const double & val)
   {
-    if (fd < 0)
-      return(-1);
-    
-    char  *buf = 0;
-    uint32_t  xe = XdrEncode(val,&buf);
-    ssize_t   rc = write(fd,buf,xe);
-
-    if (rc < 8)
-      rc = -1;
-
+    ssize_t  rc = -1;
+    if (fd >= 0) {
+      char  *buf = 0;
+      uint32_t  xe = XDRUtils::Encode(val, &buf);
+      rc = write(fd, buf, xe);
+      free(buf);
+      if (rc < 8) {
+        rc = -1;
+      }
+    }
     return(rc);
   }
   
@@ -657,7 +585,7 @@ namespace Dwm {
       int16_t  v;
       rc = read(fd,(void *)&v,sizeof(v));
       if (rc == sizeof(v))
-        val = ntohs(v);
+        val = be16toh(v);
     }
     return(rc);
   }
@@ -672,7 +600,7 @@ namespace Dwm {
       uint16_t  v;
       rc = read(fd,(void *)&v,sizeof(v));
       if (rc == sizeof(v))
-        val = ntohs(v);
+        val = be16toh(v);
     }
     return(rc);
   }
@@ -687,7 +615,7 @@ namespace Dwm {
       int32_t  v;
       rc = read(fd,(void *)&v,sizeof(v));
       if (rc == sizeof(v))
-        val = ntohl(v);
+        val = be32toh(v);
     }
     return(rc);
   }
@@ -702,7 +630,7 @@ namespace Dwm {
       uint32_t  v;
       rc = read(fd,(void *)&v,sizeof(v));
       if (rc == sizeof(v))
-        val = ntohl(v);
+        val = be32toh(v);
     }
     return(rc);
   }
@@ -749,7 +677,7 @@ namespace Dwm {
       char     buf[4];
       rc = read(fd,buf,4);
       if (rc == 4) {
-        XdrDecode(buf,val);
+        XDRUtils::Decode(buf,val);
       }
     }
     return(rc);
@@ -765,7 +693,7 @@ namespace Dwm {
       char     buf[8];
       rc = read(fd,buf,8);
       if (rc == 8) {
-        XdrDecode(buf,val);
+        XDRUtils::Decode(buf,val);
       }
     }
     return(rc);
@@ -846,7 +774,7 @@ namespace Dwm {
   {
     size_t rc = 0;
     if (f) {
-      int16_t v = htons(val);
+      int16_t v = htobe16(val);
       if (fwrite((void *)&v,sizeof(v),1,f) == 1)
         rc = sizeof(v);
     }
@@ -860,7 +788,7 @@ namespace Dwm {
   {
     size_t rc = 0;
     if (f) {
-      uint16_t v = htons(val);
+      uint16_t v = htobe16(val);
       if (fwrite((void *)&v,sizeof(v),1,f) == 1)
         rc = sizeof(v);
     }
@@ -874,7 +802,7 @@ namespace Dwm {
   {
     size_t rc = 0;
     if (f) {
-      int32_t v = htonl(val);
+      int32_t v = htobe32(val);
       if (fwrite((void *)&v,sizeof(v),1,f) == 1)
         rc = sizeof(v);
     }
@@ -888,7 +816,7 @@ namespace Dwm {
   {
     size_t rc = 0;
     if (f) {
-      uint32_t v = htonl(val);
+      uint32_t v = htobe32(val);
       if (fwrite((void *)&v,sizeof(v),1,f) == 1)
         rc = sizeof(v);
     }
@@ -933,7 +861,7 @@ namespace Dwm {
     size_t  rc = 0;
     if (f) {
       char  *buf = 0;
-      rc = XdrEncode(val,&buf);
+      rc = XDRUtils::Encode(val,&buf);
       if (fwrite((void *)buf,rc,1,f) != 1)
         rc = 0;
       free(buf);
@@ -950,7 +878,7 @@ namespace Dwm {
     
     if (f) {
       char  *buf = 0;
-      rc = XdrEncode(val,&buf);
+      rc = XDRUtils::Encode(val,&buf);
       if (fwrite((void *)buf,rc,1,f) != 1)
         rc = 0;
       free(buf);
@@ -1025,7 +953,7 @@ namespace Dwm {
       int16_t v;
       if (fread((void *)&v,sizeof(v),1,f) == 1) {
         rc = sizeof(v);
-        val = ntohs(v);
+        val = be16toh(v);
       }
     }
     return(rc);
@@ -1041,7 +969,7 @@ namespace Dwm {
       uint16_t v;
       if (fread((void *)&v,sizeof(v),1,f) == 1) {
         rc = sizeof(v);
-        val = ntohs(v);
+        val = be16toh(v);
       }
     }
     return(rc);
@@ -1057,7 +985,7 @@ namespace Dwm {
       int32_t v;
       if (fread((void *)&v,sizeof(v),1,f) == 1) {
         rc = sizeof(v);
-        val = ntohl(v);
+        val = be32toh(v);
       }
     }
     return(rc);
@@ -1073,7 +1001,7 @@ namespace Dwm {
       uint32_t v;
       if (fread((void *)&v,sizeof(v),1,f) == 1) {
         rc = sizeof(v);
-        val = ntohl(v);
+        val = be32toh(v);
       }
     }
     return(rc);
@@ -1121,7 +1049,7 @@ namespace Dwm {
     if (f) {
       char   buf[4];
       if (fread((void *)buf,4,1,f) == 1) {
-        XdrDecode(buf,val);
+        XDRUtils::Decode(buf,val);
         rc = 4;
       }
     }
@@ -1139,7 +1067,7 @@ namespace Dwm {
     if (f) {
       char   buf[8];
       if (fread((void *)buf,8,1,f) == 1) {
-        XdrDecode(buf,val);
+        XDRUtils::Decode(buf,val);
         rc = 8;
       }
     }
