@@ -1,8 +1,8 @@
 //===========================================================================
-// @(#) $Name$
-// @(#) $Id: DwmIpv4UdpHeader.cc 8388 2016-04-17 03:23:45Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/src/DwmIpv4UdpHeader.cc 11112 $
+// @(#) $Id: DwmIpv4UdpHeader.cc 11112 2020-09-07 22:51:32Z dwm $
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 2006-2007
+//  Copyright (c) Daniel W. McRobb 2006-2007, 2020
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -36,7 +36,8 @@
 
 //---------------------------------------------------------------------------
 //!  \file DwmIpv4UdpHeader.cc
-//!  \brief NOT YET DOCUMENTED
+//!  \author Daniel W. McRobb
+//!  \brief Dwm::Ipv4UdpHeader class implementation
 //---------------------------------------------------------------------------
 
 extern "C" {
@@ -48,12 +49,11 @@ extern "C" {
 #include <sstream>
 
 #include "DwmSvnTag.hh"
-#include "DwmIO.hh"
 #include "DwmIpv4UdpHeader.hh"
 #include "DwmIpv4UdpPayload.hh"
 #include "DwmIpv4Utils.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/src/DwmIpv4UdpHeader.cc 8388 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/src/DwmIpv4UdpHeader.cc 11112 $");
 
 using namespace std;
 
