@@ -1,8 +1,8 @@
 //===========================================================================
-// @(#) $Name$
-// @(#) $Id: DwmIpv6Address.cc 9898 2017-12-30 06:16:42Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/src/DwmIpv6Address.cc 11116 $
+// @(#) $Id: DwmIpv6Address.cc 11116 2020-09-07 22:55:31Z dwm $
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 2004-2007
+//  Copyright (c) Daniel W. McRobb 2004-2007, 2020
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -34,6 +34,12 @@
 //  TRADEMARK OR OTHER RIGHTS.
 //===========================================================================
 
+//---------------------------------------------------------------------------
+//!  \file DwmIpv6Address.cc
+//!  \author Daniel W. McRobb
+//!  \brief Dwm::Ipv6Address class implementation
+//---------------------------------------------------------------------------
+
 extern "C" {
   #include <sys/types.h>
   #include <sys/socket.h>  // for inet_ntop()/inet_pton()
@@ -48,11 +54,9 @@ extern "C" {
 #include <cassert>
 
 #include "DwmSvnTag.hh"
-#include "DwmReadable.hh"
-#include "DwmWritable.hh"
 #include "DwmIpv6Address.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/src/DwmIpv6Address.cc 9898 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/src/DwmIpv6Address.cc 11116 $");
 
 namespace Dwm {
 
