@@ -1,8 +1,8 @@
 //===========================================================================
-// @(#) $Name$
-// @(#) $Id: DwmMplsLabel.cc 8388 2016-04-17 03:23:45Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/src/DwmMplsLabel.cc 11087 $
+// @(#) $Id: DwmMplsLabel.cc 11087 2020-09-07 09:58:37Z dwm $
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 2007
+//  Copyright (c) Daniel W. McRobb 2007, 2020
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -36,7 +36,8 @@
 
 //---------------------------------------------------------------------------
 //!  \file DwmMplsLabel.cc
-//!  \brief NOT YET DOCUMENTED
+//!  \author Daniel W. McRobb
+//!  \brief Dwm::MplsLabel class implementation
 //---------------------------------------------------------------------------
 
 #include <cassert>
@@ -46,10 +47,12 @@
 #include "DwmSvnTag.hh"
 #include "DwmBZ2IO.hh"
 #include "DwmGZIO.hh"
-#include "DwmIO.hh"
+#include "DwmDescriptorIO.hh"
+#include "DwmFileIO.hh"
+#include "DwmStreamIO.hh"
 #include "DwmMplsLabel.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/src/DwmMplsLabel.cc 8388 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/src/DwmMplsLabel.cc 11087 $");
 
 namespace Dwm {
 
@@ -176,7 +179,7 @@ namespace Dwm {
   //------------------------------------------------------------------------
   std::istream & MplsLabel::Read(std::istream & is)
   {
-    return(IO::Read(is, _data));
+    return(StreamIO::Read(is, _data));
   }
 
   //------------------------------------------------------------------------
@@ -184,7 +187,7 @@ namespace Dwm {
   //------------------------------------------------------------------------
   std::ostream & MplsLabel::Write(std::ostream & os) const
   {
-    return(IO::Write(os, _data));
+    return(StreamIO::Write(os, _data));
   }
 
   //------------------------------------------------------------------------
@@ -192,7 +195,7 @@ namespace Dwm {
   //------------------------------------------------------------------------
   ssize_t MplsLabel::Read(int fd)
   {
-    return(IO::Read(fd, _data));
+    return(DescriptorIO::Read(fd, _data));
   }
 
   //------------------------------------------------------------------------
@@ -200,7 +203,7 @@ namespace Dwm {
   //------------------------------------------------------------------------
   ssize_t MplsLabel::Write(int fd) const
   {
-    return(IO::Write(fd, _data));
+    return(DescriptorIO::Write(fd, _data));
   }
 
   //------------------------------------------------------------------------
@@ -208,7 +211,7 @@ namespace Dwm {
   //------------------------------------------------------------------------
   size_t MplsLabel::Read(FILE *f)
   {
-    return(IO::Read(f, _data));
+    return(FileIO::Read(f, _data));
   }
 
   //------------------------------------------------------------------------
@@ -216,7 +219,7 @@ namespace Dwm {
   //------------------------------------------------------------------------
   size_t MplsLabel::Write(FILE *f) const
   {
-    return(IO::Write(f, _data));
+    return(FileIO::Write(f, _data));
   }
 
   //--------------------------------------------------------------------------
