@@ -1,8 +1,8 @@
 //===========================================================================
-// @(#) $Name$
-// @(#) $Id: DwmPacer.cc 8388 2016-04-17 03:23:45Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/src/DwmPacer.cc 11121 $
+// @(#) $Id: DwmPacer.cc 11121 2020-09-07 23:15:23Z dwm $
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 1998-2007
+//  Copyright (c) Daniel W. McRobb 1998-2007, 2020
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -36,13 +36,16 @@
 
 //---------------------------------------------------------------------------
 //!  \file DwmPacer.cc
-//!  \brief NOT YET DOCUMENTED
+//!  \author Daniel W. McRobb
+//!  \brief Dwm::Pacer class implementation
 //---------------------------------------------------------------------------
 
 extern "C" {
   #include <sys/param.h>
   #include <sys/types.h>
+#if (defined __APPLE__)
   #include <sys/sysctl.h>
+#endif
   #include <sys/time.h>
 }
 
@@ -51,7 +54,7 @@ extern "C" {
 #include "DwmSvnTag.hh"
 #include "DwmPacer.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/src/DwmPacer.cc 8388 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/src/DwmPacer.cc 11121 $");
 
 namespace Dwm {
 
