@@ -1,8 +1,8 @@
 //===========================================================================
-// @(#) $Name$
-// @(#) $Id: DwmProcessInfo.cc 10621 2020-05-02 21:51:49Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/src/DwmProcessInfo.cc 11127 $
+// @(#) $Id: DwmProcessInfo.cc 11127 2020-09-07 23:23:30Z dwm $
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 2006-2007
+//  Copyright (c) Daniel W. McRobb 2006-2007, 2020
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -36,7 +36,8 @@
 
 //---------------------------------------------------------------------------
 //!  \file DwmProcessInfo.cc
-//!  \brief NOT YET DOCUMENTED
+//!  \author Daniel W. McRobb
+//!  \brief Dwm::ProcessInfo class implementation
 //---------------------------------------------------------------------------
 
 extern "C" {
@@ -54,13 +55,14 @@ extern "C" {
 
 #include "DwmSvnTag.hh"
 #include "DwmGZIO.hh"
-#include "DwmIO.hh"
+#include "DwmIOUtils.hh"
+#include "DwmStreamIO.hh"
 #include "DwmMutex.hh"
 #include "DwmPassword.hh"
 #include "DwmProcessInfo.hh"
 #include "DwmProcessTable.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/src/DwmProcessInfo.cc 10621 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/src/DwmProcessInfo.cc 11127 $");
 
 namespace Dwm {
 
@@ -406,65 +408,65 @@ namespace Dwm {
   {
     if (is) {
       int32_t  val32;
-      if (! IO::Read(is, val32))
+      if (! StreamIO::Read(is, val32))
         goto readError;
       _id = val32;
 
-      if (! IO::Read(is, val32))
+      if (! StreamIO::Read(is, val32))
         goto readError;
       _parentId = val32;
 
-      if (! IO::Read(is, val32))
+      if (! StreamIO::Read(is, val32))
         goto readError;
       _groupId = val32;
 
-      if (! IO::Read(is, _controllingTty))
+      if (! StreamIO::Read(is, _controllingTty))
         goto readError;
 
-      if (! IO::Read(is, val32))
+      if (! StreamIO::Read(is, val32))
         goto readError;
       _sessionId = val32;
 
-      if (! IO::Read(is, val32))
+      if (! StreamIO::Read(is, val32))
         goto readError;
       _terminalSessionId = val32;
       
-      if (! IO::Read(is, val32))
+      if (! StreamIO::Read(is, val32))
         goto readError;
       _effectiveUserId = val32;
 
-      if (! IO::Read(is, val32))
+      if (! StreamIO::Read(is, val32))
         goto readError;
       _realUserId = val32;
 
-      if (! IO::Read(is, val32))
+      if (! StreamIO::Read(is, val32))
         goto readError;
       _savedEffectiveUserId = val32;
 
-      if (! IO::Read(is, val32))
+      if (! StreamIO::Read(is, val32))
         goto readError;
       _realGroupId = val32;
 
-      if (! IO::Read(is, val32))
+      if (! StreamIO::Read(is, val32))
         goto readError;
       _savedEffectiveGroupId = val32;
 
-      if (! IO::Read(is, _command))
+      if (! StreamIO::Read(is, _command))
         goto readError;
 
-      if (! IO::Read(is, _startTime))
+      if (! StreamIO::Read(is, _startTime))
         goto readError;
 
-      if (! IO::Read(is, _size))
+      if (! StreamIO::Read(is, _size))
         goto readError;
 
-      if (! IO::Read(is, _residentSetSize))
+      if (! StreamIO::Read(is, _residentSetSize))
         goto readError;
 
-      if (! IO::Read(is, _rusage))
+      if (! StreamIO::Read(is, _rusage))
         goto readError;
 
-      if (!IO::Read(is, _args))
+      if (!StreamIO::Read(is, _args))
         goto readError;
     }
     readError:
@@ -479,64 +481,64 @@ namespace Dwm {
   {
     if (os) {
       int32_t  val32 = _id;
-      if (! IO::Write(os, val32))
+      if (! StreamIO::Write(os, val32))
         goto writeError;
 
       val32 = _parentId;
-      if (! IO::Write(os, val32))
+      if (! StreamIO::Write(os, val32))
         goto writeError;
 
       val32 = _groupId;
-      if (! IO::Write(os, val32))
+      if (! StreamIO::Write(os, val32))
         goto writeError;
 
-      if (! IO::Write(os, _controllingTty))
+      if (! StreamIO::Write(os, _controllingTty))
         goto writeError;
       
       val32 = _sessionId;
-      if (! IO::Write(os, val32))
+      if (! StreamIO::Write(os, val32))
         goto writeError;
 
       val32 = _terminalSessionId;
-      if (! IO::Write(os, val32))
+      if (! StreamIO::Write(os, val32))
         goto writeError;
 
       val32 = _effectiveUserId;
-      if (! IO::Write(os, val32))
+      if (! StreamIO::Write(os, val32))
         goto writeError;
 
       val32 = _realUserId;
-      if (! IO::Write(os, val32))
+      if (! StreamIO::Write(os, val32))
         goto writeError;
 
       val32 = _savedEffectiveUserId;
-      if (! IO::Write(os, val32))
+      if (! StreamIO::Write(os, val32))
         goto writeError;
 
       val32 = _realGroupId;
-      if (! IO::Write(os, val32))
+      if (! StreamIO::Write(os, val32))
         goto writeError;
 
       val32 = _savedEffectiveGroupId;
-      if (! IO::Write(os, val32))
+      if (! StreamIO::Write(os, val32))
         goto writeError;
 
-      if (! IO::Write(os, _command))
+      if (! StreamIO::Write(os, _command))
         goto writeError;
 
-      if (! IO::Write(os, _startTime))
+      if (! StreamIO::Write(os, _startTime))
         goto writeError;
 
-      if (! IO::Write(os, _size))
+      if (! StreamIO::Write(os, _size))
         goto writeError;
 
-      if (! IO::Write(os, _residentSetSize))
+      if (! StreamIO::Write(os, _residentSetSize))
         goto writeError;
 
-      if (! IO::Write(os, _rusage))
+      if (! StreamIO::Write(os, _rusage))
         goto writeError;
 
-      if (! IO::Write(os, _args))
+      if (! StreamIO::Write(os, _args))
         goto writeError;
     }
     writeError:
@@ -556,97 +558,97 @@ namespace Dwm {
     
     int32_t  val32;
     int  bytesRead = GZIO::Read(gzf, val32);
-    if (bytesRead != (int)IO::StreamedLength(val32))
+    if (bytesRead != (int)IOUtils::StreamedLength(val32))
       goto readError;
     _id = val32;
     rc += bytesRead;
     
     bytesRead = GZIO::Read(gzf, val32);
-    if (bytesRead != (int)IO::StreamedLength(val32))
+    if (bytesRead != (int)IOUtils::StreamedLength(val32))
       goto readError;
     _parentId = val32;
     rc += bytesRead;
     
     bytesRead = GZIO::Read(gzf, val32);
-    if (bytesRead != (int)IO::StreamedLength(val32))
+    if (bytesRead != (int)IOUtils::StreamedLength(val32))
       goto readError;
     _groupId = val32;
     rc += bytesRead;
     
     bytesRead = GZIO::Read(gzf, _controllingTty);
-    if (bytesRead != (int)IO::StreamedLength(_controllingTty))
+    if (bytesRead != (int)IOUtils::StreamedLength(_controllingTty))
       goto readError;
     rc += bytesRead;
 
     bytesRead = GZIO::Read(gzf, val32);
-    if (bytesRead != (int)IO::StreamedLength(val32))
+    if (bytesRead != (int)IOUtils::StreamedLength(val32))
       goto readError;
     _sessionId = val32;
     rc += bytesRead;
     
     bytesRead = GZIO::Read(gzf, val32);
-    if (bytesRead != (int)IO::StreamedLength(val32))
+    if (bytesRead != (int)IOUtils::StreamedLength(val32))
       goto readError;
     _terminalSessionId = val32;
     rc += bytesRead;
     
     bytesRead = GZIO::Read(gzf, val32);
-    if (bytesRead != (int)IO::StreamedLength(val32))
+    if (bytesRead != (int)IOUtils::StreamedLength(val32))
       goto readError;
     _effectiveUserId = val32;
     rc += bytesRead;
     
     bytesRead = GZIO::Read(gzf, val32);
-    if (bytesRead != (int)IO::StreamedLength(val32))
+    if (bytesRead != (int)IOUtils::StreamedLength(val32))
       goto readError;
     _realUserId = val32;
     rc += bytesRead;
     
     bytesRead = GZIO::Read(gzf, val32);
-    if (bytesRead != (int)IO::StreamedLength(val32))
+    if (bytesRead != (int)IOUtils::StreamedLength(val32))
       goto readError;
     _savedEffectiveUserId = val32;
     rc += bytesRead;
     
     bytesRead = GZIO::Read(gzf, val32);
-    if (bytesRead != (int)IO::StreamedLength(val32))
+    if (bytesRead != (int)IOUtils::StreamedLength(val32))
       goto readError;
     _realGroupId = val32;
     rc += bytesRead;
     
     bytesRead = GZIO::Read(gzf, val32);
-    if (bytesRead != (int)IO::StreamedLength(val32))
+    if (bytesRead != (int)IOUtils::StreamedLength(val32))
       goto readError;
     _savedEffectiveGroupId = val32;
     rc += bytesRead;
     
     bytesRead = GZIO::Read(gzf, _command);
-    if (bytesRead != (int)IO::StreamedLength(_command))
+    if (bytesRead != (int)IOUtils::StreamedLength(_command))
       goto readError;
     rc += bytesRead;
     
     bytesRead = GZIO::Read(gzf, _startTime);
-    if (bytesRead != (int)IO::StreamedLength(_startTime))
+    if (bytesRead != (int)IOUtils::StreamedLength(_startTime))
       goto readError;
     rc += bytesRead;
 
     bytesRead = GZIO::Read(gzf, _size);
-    if (bytesRead != (int)IO::StreamedLength(_size))
+    if (bytesRead != (int)IOUtils::StreamedLength(_size))
       goto readError;
     rc += bytesRead;
     
     bytesRead = GZIO::Read(gzf, _residentSetSize);
-    if (bytesRead != (int)IO::StreamedLength(_residentSetSize))
+    if (bytesRead != (int)IOUtils::StreamedLength(_residentSetSize))
       goto readError;
     rc += bytesRead;
     
     bytesRead = GZIO::Read(gzf, _rusage);
-    if (bytesRead != (int)IO::StreamedLength(_rusage))
+    if (bytesRead != (int)IOUtils::StreamedLength(_rusage))
       goto readError;
     rc += bytesRead;
 
     bytesRead = GZIO::Read(gzf, _args);
-    if (bytesRead != (int)IO::StreamedLength(_args))
+    if (bytesRead != (int)IOUtils::StreamedLength(_args))
       goto readError;
     rc += bytesRead;
 
@@ -668,96 +670,96 @@ namespace Dwm {
     int  rc = 0;
     int32_t  val32 = _id;
     int  bytesWritten = GZIO::Write(gzf, val32);
-    if (bytesWritten != (int)IO::StreamedLength(val32))
+    if (bytesWritten != (int)IOUtils::StreamedLength(val32))
         goto writeError;
     rc += bytesWritten;
     
     val32 = _parentId;
     bytesWritten = GZIO::Write(gzf, val32);
-    if (bytesWritten != (int)IO::StreamedLength(val32))
+    if (bytesWritten != (int)IOUtils::StreamedLength(val32))
       goto writeError;
     rc += bytesWritten;
 
     val32 = _groupId;
     bytesWritten = GZIO::Write(gzf, val32);
-    if (bytesWritten != (int)IO::StreamedLength(val32))
+    if (bytesWritten != (int)IOUtils::StreamedLength(val32))
       goto writeError;
     rc += bytesWritten;
     
     bytesWritten = GZIO::Write(gzf, _controllingTty);
-    if (bytesWritten != (int)IO::StreamedLength(_controllingTty))
+    if (bytesWritten != (int)IOUtils::StreamedLength(_controllingTty))
       goto writeError;
     rc += bytesWritten;
     
     val32 = _sessionId;
     bytesWritten = GZIO::Write(gzf, val32);
-    if (bytesWritten != (int)IO::StreamedLength(val32))
+    if (bytesWritten != (int)IOUtils::StreamedLength(val32))
       goto writeError;
     rc += bytesWritten;
 
     val32 = _terminalSessionId;
     bytesWritten = GZIO::Write(gzf, val32);
-    if (bytesWritten != (int)IO::StreamedLength(val32))
+    if (bytesWritten != (int)IOUtils::StreamedLength(val32))
       goto writeError;
     rc += bytesWritten;
 
     val32 = _effectiveUserId;
     bytesWritten = GZIO::Write(gzf, val32);
-    if (bytesWritten != (int)IO::StreamedLength(val32))
+    if (bytesWritten != (int)IOUtils::StreamedLength(val32))
       goto writeError;
     rc += bytesWritten;
 
     val32 = _realUserId;
     bytesWritten = GZIO::Write(gzf, val32);
-    if (bytesWritten != (int)IO::StreamedLength(val32))
+    if (bytesWritten != (int)IOUtils::StreamedLength(val32))
       goto writeError;
     rc += bytesWritten;
 
     val32 = _savedEffectiveUserId;
     bytesWritten = GZIO::Write(gzf, val32);
-    if (bytesWritten != (int)IO::StreamedLength(val32))
+    if (bytesWritten != (int)IOUtils::StreamedLength(val32))
       goto writeError;
     rc += bytesWritten;
 
     val32 = _realGroupId;
     bytesWritten = GZIO::Write(gzf, val32);
-    if (bytesWritten != (int)IO::StreamedLength(val32))
+    if (bytesWritten != (int)IOUtils::StreamedLength(val32))
       goto writeError;
     rc += bytesWritten;
 
     val32 = _savedEffectiveGroupId;
     bytesWritten = GZIO::Write(gzf, val32);
-    if (bytesWritten != (int)IO::StreamedLength(val32))
+    if (bytesWritten != (int)IOUtils::StreamedLength(val32))
       goto writeError;
     rc += bytesWritten;
 
     bytesWritten = GZIO::Write(gzf, _command);
-    if (bytesWritten != (int)IO::StreamedLength(_command))
+    if (bytesWritten != (int)IOUtils::StreamedLength(_command))
       goto writeError;
     rc += bytesWritten;
     
     bytesWritten = GZIO::Write(gzf, _startTime);
-    if (bytesWritten != (int)IO::StreamedLength(_startTime))
+    if (bytesWritten != (int)IOUtils::StreamedLength(_startTime))
       goto writeError;
     rc += bytesWritten;
     
     bytesWritten = GZIO::Write(gzf, _size);
-    if (bytesWritten != (int)IO::StreamedLength(_size))
+    if (bytesWritten != (int)IOUtils::StreamedLength(_size))
       goto writeError;
     rc += bytesWritten;
     
     bytesWritten = GZIO::Write(gzf, _residentSetSize);
-    if (bytesWritten != (int)IO::StreamedLength(_residentSetSize))
+    if (bytesWritten != (int)IOUtils::StreamedLength(_residentSetSize))
       goto writeError;
     rc += bytesWritten;
 
     bytesWritten = GZIO::Write(gzf, _rusage);
-    if (bytesWritten != (int)IO::StreamedLength(_rusage))
+    if (bytesWritten != (int)IOUtils::StreamedLength(_rusage))
       goto writeError;
     rc += bytesWritten;
     
     bytesWritten = GZIO::Write(gzf, _args);
-    if (bytesWritten != (int)IO::StreamedLength(_args))
+    if (bytesWritten != (int)IOUtils::StreamedLength(_args))
       goto writeError;
     rc += bytesWritten;
     
@@ -767,53 +769,17 @@ namespace Dwm {
       return(-1);
   }
   
-  //--------------------------------------------------------------------------
-  //!  
-  //--------------------------------------------------------------------------
-  ssize_t ProcessInfo::Read(int fd)
-  {
-    assert(string("ProcessInfo::Read(int fd)") == "Implemented");
-    return(-1);
-  }
-  
-  //--------------------------------------------------------------------------
-  //!  
-  //--------------------------------------------------------------------------
-  ssize_t ProcessInfo::Write(int fd) const
-  {
-    assert(string("ProcessInfo::Write(int fd)") == "Implemented");
-    return(-1);
-  }
-  
-  //--------------------------------------------------------------------------
-  //!  
-  //--------------------------------------------------------------------------
-  size_t ProcessInfo::Read(FILE * f)
-  {
-    assert(string("ProcessInfo::Read(FILE * f)") == "Implemented");
-    return(0);
-  }
-  
-  //--------------------------------------------------------------------------
-  //!  
-  //--------------------------------------------------------------------------
-  size_t ProcessInfo::Write(FILE *f) const
-  {
-    assert(string("ProcessInfo::Write(FILE *f)") == "Implemented");
-    return(0);
-  }
-  
   //--------------------------------------------------------------------------
   //!  
   //--------------------------------------------------------------------------
   uint32_t ProcessInfo::StreamedLength() const
   {
     uint32_t  rc = 8 * sizeof(uint32_t);
-    rc += IO::StreamedLength(_command);
-    rc += IO::StreamedLength(_startTime);
-    rc += IO::StreamedLength(_size);
-    rc += IO::StreamedLength(_residentSetSize);
-    rc += IO::StreamedLength(_rusage);
+    rc += IOUtils::StreamedLength(_command);
+    rc += IOUtils::StreamedLength(_startTime);
+    rc += IOUtils::StreamedLength(_size);
+    rc += IOUtils::StreamedLength(_residentSetSize);
+    rc += IOUtils::StreamedLength(_rusage);
     
     return(rc);
   }
