@@ -1,8 +1,8 @@
 //===========================================================================
-// @(#) $Name$
-// @(#) $Id: DwmRusage.cc 10621 2020-05-02 21:51:49Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/src/DwmRusage.cc 11132 $
+// @(#) $Id: DwmRusage.cc 11132 2020-09-07 23:34:09Z dwm $
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 2006-2007
+//  Copyright (c) Daniel W. McRobb 2006-2007, 2020
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -36,7 +36,8 @@
 
 //---------------------------------------------------------------------------
 //!  \file DwmRusage.cc
-//!  \brief NOT YET DOCUMENTED
+//!  \author Daniel W. McRobb
+//!  \brief Dwm::Rusage class implementation
 //---------------------------------------------------------------------------
 
 #include <cassert>
@@ -45,12 +46,14 @@
 
 #include "DwmSvnTag.hh"
 #include "DwmEngFormat.hh"
+#include "DwmDescriptorIO.hh"
 #include "DwmGZIO.hh"
-#include "DwmIO.hh"
+#include "DwmIOUtils.hh"
+#include "DwmStreamIO.hh"
 #include "DwmSysLogger.hh"
 #include "DwmRusage.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/src/DwmRusage.cc 10621 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/src/DwmRusage.cc 11132 $");
 
 using namespace std;
 
@@ -305,22 +308,22 @@ namespace Dwm {
   std::istream & Rusage::Read(std::istream & is)
   {
     if (is) {
-      if (! IO::Read(is, _userTime))                       goto readError;
-      if (! IO::Read(is, _systemTime))                     goto readError;
-      if (! IO::Read(is, _maxResidentSetSize))             goto readError;
-      if (! IO::Read(is, _integralSharedTextMemorySize))   goto readError;
-      if (! IO::Read(is, _integralUnsharedDataSize))       goto readError;
-      if (! IO::Read(is, _integralUnsharedStackSize))      goto readError;
-      if (! IO::Read(is, _pageReclaims))                   goto readError;
-      if (! IO::Read(is, _pageFaults))                     goto readError;
-      if (! IO::Read(is, _swaps))                          goto readError;
-      if (! IO::Read(is, _blockInputOperations))           goto readError;
-      if (! IO::Read(is, _blockOutputOperations))          goto readError;
-      if (! IO::Read(is, _messagesSent))                   goto readError;
-      if (! IO::Read(is, _messagesReceived))               goto readError;
-      if (! IO::Read(is, _signalsReceived))                goto readError;
-      if (! IO::Read(is, _voluntaryContextSwitches))       goto readError;
-      IO::Read(is, _involuntaryContextSwitches);
+      if (! StreamIO::Read(is, _userTime))                       goto readError;
+      if (! StreamIO::Read(is, _systemTime))                     goto readError;
+      if (! StreamIO::Read(is, _maxResidentSetSize))             goto readError;
+      if (! StreamIO::Read(is, _integralSharedTextMemorySize))   goto readError;
+      if (! StreamIO::Read(is, _integralUnsharedDataSize))       goto readError;
+      if (! StreamIO::Read(is, _integralUnsharedStackSize))      goto readError;
+      if (! StreamIO::Read(is, _pageReclaims))                   goto readError;
+      if (! StreamIO::Read(is, _pageFaults))                     goto readError;
+      if (! StreamIO::Read(is, _swaps))                          goto readError;
+      if (! StreamIO::Read(is, _blockInputOperations))           goto readError;
+      if (! StreamIO::Read(is, _blockOutputOperations))          goto readError;
+      if (! StreamIO::Read(is, _messagesSent))                   goto readError;
+      if (! StreamIO::Read(is, _messagesReceived))               goto readError;
+      if (! StreamIO::Read(is, _signalsReceived))                goto readError;
+      if (! StreamIO::Read(is, _voluntaryContextSwitches))       goto readError;
+      StreamIO::Read(is, _involuntaryContextSwitches);
     }
   readError:
     return(is);
@@ -332,22 +335,22 @@ namespace Dwm {
   std::ostream & Rusage::Write(std::ostream & os) const
   {
     if (os) {
-      if (! IO::Write(os, _userTime))                        goto writeError;
-      if (! IO::Write(os, _systemTime))                      goto writeError;
-      if (! IO::Write(os, _maxResidentSetSize))              goto writeError;
-      if (! IO::Write(os, _integralSharedTextMemorySize))    goto writeError;
-      if (! IO::Write(os, _integralUnsharedDataSize))        goto writeError;
-      if (! IO::Write(os, _integralUnsharedStackSize))       goto writeError;
-      if (! IO::Write(os, _pageReclaims))                    goto writeError;
-      if (! IO::Write(os, _pageFaults))                      goto writeError;
-      if (! IO::Write(os, _swaps))                           goto writeError;
-      if (! IO::Write(os, _blockInputOperations))            goto writeError;
-      if (! IO::Write(os, _blockOutputOperations))           goto writeError;
-      if (! IO::Write(os, _messagesSent))                    goto writeError;
-      if (! IO::Write(os, _messagesReceived))                goto writeError;
-      if (! IO::Write(os, _signalsReceived))                 goto writeError;
-      if (! IO::Write(os, _voluntaryContextSwitches))        goto writeError;
-      IO::Write(os, _involuntaryContextSwitches);
+      if (! StreamIO::Write(os, _userTime))                        goto writeError;
+      if (! StreamIO::Write(os, _systemTime))                      goto writeError;
+      if (! StreamIO::Write(os, _maxResidentSetSize))              goto writeError;
+      if (! StreamIO::Write(os, _integralSharedTextMemorySize))    goto writeError;
+      if (! StreamIO::Write(os, _integralUnsharedDataSize))        goto writeError;
+      if (! StreamIO::Write(os, _integralUnsharedStackSize))       goto writeError;
+      if (! StreamIO::Write(os, _pageReclaims))                    goto writeError;
+      if (! StreamIO::Write(os, _pageFaults))                      goto writeError;
+      if (! StreamIO::Write(os, _swaps))                           goto writeError;
+      if (! StreamIO::Write(os, _blockInputOperations))            goto writeError;
+      if (! StreamIO::Write(os, _blockOutputOperations))           goto writeError;
+      if (! StreamIO::Write(os, _messagesSent))                    goto writeError;
+      if (! StreamIO::Write(os, _messagesReceived))                goto writeError;
+      if (! StreamIO::Write(os, _signalsReceived))                 goto writeError;
+      if (! StreamIO::Write(os, _voluntaryContextSwitches))        goto writeError;
+      StreamIO::Write(os, _involuntaryContextSwitches);
     }
   writeError:
     return(os);
@@ -362,7 +365,7 @@ namespace Dwm {
     bool  rc = false;
     if (gzf) {
       int  bytesRead = GZIO::Read(gzf, val);
-      if (bytesRead == (int)IO::StreamedLength(val)) {
+      if (bytesRead == (int)IOUtils::StreamedLength(val)) {
         rc = true;
         totalBytes += bytesRead;
       }
@@ -413,7 +416,7 @@ namespace Dwm {
     bool  rc = false;
     if (gzf) {
       int  bytesWritten = GZIO::Write(gzf, val);
-      if (bytesWritten == (int)IO::StreamedLength(val)) {
+      if (bytesWritten == (int)IOUtils::StreamedLength(val)) {
         rc = true;
         totalBytes += bytesWritten;
       }
@@ -462,8 +465,8 @@ namespace Dwm {
   {
     bool  rc = false;
     if (fd >= 0) {
-      ssize_t  bytesRead = IO::Read(fd, val);
-      if (bytesRead == (int)IO::StreamedLength(val)) {
+      ssize_t  bytesRead = DescriptorIO::Read(fd, val);
+      if (bytesRead == (int)IOUtils::StreamedLength(val)) {
         rc = true;
         totalBytes += bytesRead;
       }
@@ -513,8 +516,8 @@ namespace Dwm {
   {
     bool  rc = false;
     if (fd >= 0) {
-      ssize_t  bytesWritten = IO::Write(fd, val);
-      if (bytesWritten == (int)IO::StreamedLength(val)) {
+      ssize_t  bytesWritten = DescriptorIO::Write(fd, val);
+      if (bytesWritten == (int)IOUtils::StreamedLength(val)) {
         rc = true;
         totalBytes += bytesWritten;
       }
@@ -555,45 +558,27 @@ namespace Dwm {
     return(-1);
   }
   
-  //--------------------------------------------------------------------------
-  //!  
-  //--------------------------------------------------------------------------
-  size_t Rusage::Read(FILE * f)
-  {
-    assert(string("Rusage::Read(FILE *f)") == "Implemented");
-    return(0);
-  }
-  
-  //--------------------------------------------------------------------------
-  //!  
-  //--------------------------------------------------------------------------
-  size_t Rusage::Write(FILE *f) const
-  {
-    assert(string("Rusage::Write(FILE *f)") == "Implemented");
-    return(0);
-  }
-
   //--------------------------------------------------------------------------
   //!  
   //--------------------------------------------------------------------------
   uint32_t Rusage::StreamedLength() const
   {
-    uint32_t  rc = IO::StreamedLength(_userTime);
-    rc += IO::StreamedLength(_systemTime);
-    rc += IO::StreamedLength(_maxResidentSetSize);
-    rc += IO::StreamedLength(_integralSharedTextMemorySize);
-    rc += IO::StreamedLength(_integralUnsharedDataSize);
-    rc += IO::StreamedLength(_integralUnsharedStackSize);
-    rc += IO::StreamedLength(_pageReclaims);
-    rc += IO::StreamedLength(_pageFaults);
-    rc += IO::StreamedLength(_swaps);
-    rc += IO::StreamedLength(_blockInputOperations);
-    rc += IO::StreamedLength(_blockOutputOperations);
-    rc += IO::StreamedLength(_messagesSent);
-    rc += IO::StreamedLength(_messagesReceived);
-    rc += IO::StreamedLength(_signalsReceived);
-    rc += IO::StreamedLength(_voluntaryContextSwitches);
-    rc += IO::StreamedLength(_involuntaryContextSwitches);
+    uint32_t  rc = IOUtils::StreamedLength(_userTime);
+    rc += IOUtils::StreamedLength(_systemTime);
+    rc += IOUtils::StreamedLength(_maxResidentSetSize);
+    rc += IOUtils::StreamedLength(_integralSharedTextMemorySize);
+    rc += IOUtils::StreamedLength(_integralUnsharedDataSize);
+    rc += IOUtils::StreamedLength(_integralUnsharedStackSize);
+    rc += IOUtils::StreamedLength(_pageReclaims);
+    rc += IOUtils::StreamedLength(_pageFaults);
+    rc += IOUtils::StreamedLength(_swaps);
+    rc += IOUtils::StreamedLength(_blockInputOperations);
+    rc += IOUtils::StreamedLength(_blockOutputOperations);
+    rc += IOUtils::StreamedLength(_messagesSent);
+    rc += IOUtils::StreamedLength(_messagesReceived);
+    rc += IOUtils::StreamedLength(_signalsReceived);
+    rc += IOUtils::StreamedLength(_voluntaryContextSwitches);
+    rc += IOUtils::StreamedLength(_involuntaryContextSwitches);
     return(rc);
   }
 
