@@ -1,8 +1,8 @@
 //===========================================================================
-// @(#) $Name$
-// @(#) $Id: DwmTimeInterval.cc 8388 2016-04-17 03:23:45Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/src/DwmTimeInterval.cc 11141 $
+// @(#) $Id: DwmTimeInterval.cc 11141 2020-09-07 23:50:25Z dwm $
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 2005-2007
+//  Copyright (c) Daniel W. McRobb 2005-2007, 2020
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -36,16 +36,19 @@
 
 //---------------------------------------------------------------------------
 //!  \file DwmTimeInterval.cc
+//!  \author Daniel W. McRobb
 //!  \brief Dwm::TimeInterval class implementation
 //---------------------------------------------------------------------------
 
 #include "DwmSvnTag.hh"
 #include "DwmTimeInterval.hh"
-#include "DwmIO.hh"
+#include "DwmDescriptorIO.hh"
+#include "DwmFileIO.hh"
+#include "DwmStreamIO.hh"
 #include "DwmBZ2IO.hh"
 #include "DwmGZIO.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/src/DwmTimeInterval.cc 8388 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/src/DwmTimeInterval.cc 11141 $");
 
 namespace Dwm {
 
@@ -123,7 +126,7 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   std::istream & TimeInterval::Read(std::istream & is)
   {
-    return(IO::Read(is, _data));
+    return(StreamIO::Read(is, _data));
   }
   
   //--------------------------------------------------------------------------
@@ -131,7 +134,7 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   std::ostream & TimeInterval::Write(std::ostream & os) const
   {
-    return(IO::Write(os, _data));
+    return(StreamIO::Write(os, _data));
   }
   
   //--------------------------------------------------------------------------
@@ -139,7 +142,7 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   size_t TimeInterval::Read(FILE *f)
   {
-    return(IO::Read(f, _data));
+    return(FileIO::Read(f, _data));
   }
   
   //--------------------------------------------------------------------------
@@ -147,7 +150,7 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   size_t TimeInterval::Write(FILE *f) const
   {
-    return(IO::Write(f, _data));
+    return(FileIO::Write(f, _data));
   }
   
   //--------------------------------------------------------------------------
@@ -155,7 +158,7 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   ssize_t TimeInterval::Read(int fd)
   {
-    return(IO::Read(fd, _data));
+    return(DescriptorIO::Read(fd, _data));
   }
   
   //--------------------------------------------------------------------------
@@ -163,7 +166,7 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   ssize_t TimeInterval::Write(int fd) const
   {
-    return(IO::Write(fd, _data));
+    return(DescriptorIO::Write(fd, _data));
   }
   
   //--------------------------------------------------------------------------
