@@ -1,8 +1,8 @@
 //===========================================================================
-// @(#) $Name$
-// @(#) $Id: DwmTimeValue.cc 8388 2016-04-17 03:23:45Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/src/DwmTimeValue.cc 11144 $
+// @(#) $Id: DwmTimeValue.cc 11144 2020-09-07 23:52:52Z dwm $
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 2005-2007
+//  Copyright (c) Daniel W. McRobb 2005-2007, 2020
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -34,15 +34,23 @@
 //  TRADEMARK OR OTHER RIGHTS.
 //===========================================================================
 
+//---------------------------------------------------------------------------
+//!  \file DwmTimeValue.cc
+//!  \author Daniel W. McRobb
+//!  \brief Dwm::TimeValue class implementation
+//---------------------------------------------------------------------------
+
 #include <cassert>
 
 #include "DwmSvnTag.hh"
 #include "DwmGZIO.hh"
 #include "DwmBZ2IO.hh"
-#include "DwmIO.hh"
+#include "DwmDescriptorIO.hh"
+#include "DwmFileIO.hh"
+#include "DwmStreamIO.hh"
 #include "DwmTimeValue.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/src/DwmTimeValue.cc 8388 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/src/DwmTimeValue.cc 11144 $");
 
 namespace Dwm {
 
@@ -251,8 +259,8 @@ namespace Dwm {
     _secs  = 0;
     _usecs = 0;
     if (is)
-      if (IO::Read(is, _secs))
-        IO::Read(is, _usecs);
+      if (StreamIO::Read(is, _secs))
+        StreamIO::Read(is, _usecs);
     return(is);
   }
   
@@ -262,8 +270,8 @@ namespace Dwm {
   std::ostream & TimeValue::Write(std::ostream & os) const
   {
     if (os)
-      if (IO::Write(os, _secs))
-        IO::Write(os, _usecs);
+      if (StreamIO::Write(os, _secs))
+        StreamIO::Write(os, _usecs);
     return(os);
   }
   
@@ -276,8 +284,8 @@ namespace Dwm {
     _secs  = 0;
     _usecs = 0;
     if (f)
-      if (IO::Read(f, _secs) > 0)
-        if (IO::Read(f, _usecs) > 0)
+      if (FileIO::Read(f, _secs) > 0)
+        if (FileIO::Read(f, _usecs) > 0)
           rc = 1;
     return(rc);
   }
@@ -289,8 +297,8 @@ namespace Dwm {
   {
     size_t  rc = 0;
     if (f)
-      if (IO::Write(f, _secs) > 0)
-        if (IO::Write(f, _usecs) > 0)
+      if (FileIO::Write(f, _secs) > 0)
+        if (FileIO::Write(f, _usecs) > 0)
           rc = 1;
     return(rc);
   }
@@ -304,10 +312,10 @@ namespace Dwm {
     _secs  = 0;
     _usecs = 0;
     if (fd >= 0) {
-      ssize_t  bytesRead = IO::Read(fd, _secs);
+      ssize_t  bytesRead = DescriptorIO::Read(fd, _secs);
       if (bytesRead == sizeof(_secs)) {
         rc = bytesRead;
-        bytesRead = IO::Read(fd, _usecs);
+        bytesRead = DescriptorIO::Read(fd, _usecs);
         if (bytesRead == sizeof(_usecs))
           rc += bytesRead;
         else
@@ -324,10 +332,10 @@ namespace Dwm {
   {
     ssize_t  rc = -1;
     if (fd >= 0) {
-      ssize_t  bytesWritten = IO::Write(fd, _secs);
+      ssize_t  bytesWritten = DescriptorIO::Write(fd, _secs);
       if (bytesWritten == sizeof(_secs)) {
         rc = bytesWritten;
-        bytesWritten = IO::Write(fd, _usecs);
+        bytesWritten = DescriptorIO::Write(fd, _usecs);
         if (bytesWritten == sizeof(_usecs))
           rc += bytesWritten;
         else
