@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/src/DwmXDRUtils.cc 10964 $
-// @(#) $Id: DwmXDRUtils.cc 10964 2020-08-24 07:08:29Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/src/DwmXDRUtils.cc 11084 $
+// @(#) $Id: DwmXDRUtils.cc 11084 2020-09-06 04:57:40Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2020
 //  All rights reserved.
@@ -37,7 +37,7 @@
 //---------------------------------------------------------------------------
 //!  \file DwmXDRUtils.cc
 //!  \author Daniel W. McRobb
-//!  \brief NOT YET DOCUMENTED
+//!  \brief Dwm::XDRUtils class implementation
 //---------------------------------------------------------------------------
 
 extern "C" {
@@ -45,9 +45,14 @@ extern "C" {
   #include <rpc/xdr.h>
 }
 
+#include <cassert>
+#include <cstdlib>
+
 #include "DwmSvnTag.hh"
 #include "DwmXDRUtils.hh"
 
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/src/DwmXDRUtils.cc 11084 $");
+
 namespace Dwm {
 
   //--------------------------------------------------------------------------
@@ -98,6 +103,71 @@ namespace Dwm {
     xdr_destroy(&xdrs);
     return rc;
   }
+
+  //--------------------------------------------------------------------------
+  //!  
+  //--------------------------------------------------------------------------
+  uint32_t XDRUtils::Encode(float val, char **buf)
+  {
+    float value = val;
+    XDR   xdrs;
+    if (*buf) {
+      free(*buf);
+    }
+    *buf = (char *)malloc(4);
+    assert(*buf);
+    xdrmem_create(&xdrs, *buf, 4, XDR_ENCODE);
+    xdr_float(&xdrs, &value);
+    xdr_destroy((&xdrs));
+    return(4);
+  }
   
+  //--------------------------------------------------------------------------
+  //!  
+  //--------------------------------------------------------------------------
+  void XDRUtils::Decode(char *buf, float & val)
+  {
+    assert(buf);
+    float  value;
+    XDR    xdrs;
+    xdrmem_create(&xdrs, buf, 4, XDR_DECODE);
+    xdr_float(&xdrs, &value);
+    val = value;
+    xdr_destroy((&xdrs));
+    return;
+  }
+  
+  //--------------------------------------------------------------------------
+  //!  
+  //--------------------------------------------------------------------------
+  uint32_t XDRUtils::Encode(double val, char **buf)
+  {
+    double  value = val;
+    XDR   xdrs;
+    if (*buf) {
+      free(*buf);
+    }
+    *buf = (char *)malloc(8);
+    assert(*buf);
+    xdrmem_create(&xdrs, *buf, 8, XDR_ENCODE);
+    xdr_double(&xdrs, &value);
+    xdr_destroy((&xdrs));
+    return(8);
+  }
+  
+  //--------------------------------------------------------------------------
+  //!  
+  //--------------------------------------------------------------------------
+  void XDRUtils::Decode(char *buf, double & val)
+  {
+    assert(buf);
+    double  value;
+    XDR     xdrs;
+    xdrmem_create(&xdrs, buf, 8, XDR_DECODE);
+    xdr_double(&xdrs, &value);
+    val = value;
+    xdr_destroy((&xdrs));
+    return;
+  }
   
 }  // namespace Dwm
