@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestDwmBZ2IO.cc 9113 $
-// @(#) $Id: TestDwmBZ2IO.cc 9113 2017-04-14 22:53:13Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestDwmBZ2IO.cc 11071 $
+// @(#) $Id: TestDwmBZ2IO.cc 11071 2020-09-05 15:20:31Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2004-2007, 2016
 //  All rights reserved.
@@ -58,7 +58,7 @@ extern "C" {
 using namespace std;
 using namespace Dwm;
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestDwmBZ2IO.cc 9113 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestDwmBZ2IO.cc 11071 $");
 
 static const char      k_charVal   = 'a';
 static const uint8_t   k_ucharVal  = 0xF0;
@@ -207,12 +207,12 @@ static bool ReadTestBlobs(BZFILE *bzf, uint32_t numBlobs)
 static bool BZ2IOTest()
 {
   bool  rc = false;
-  BZFILE  *bzf = BZ2_bzopen("/tmp/DWMBZ2IOTest.gz","wb");
+  BZFILE  *bzf = BZ2_bzopen("/tmp/DWMBZ2IOTest.bz2","wb");
   if (bzf) {
     if (WriteTestBlobs(bzf,3)) {
       BZ2_bzclose(bzf);
       
-      bzf = BZ2_bzopen("/tmp/DWMBZ2IOTest.gz","rb");
+      bzf = BZ2_bzopen("/tmp/DWMBZ2IOTest.bz2","rb");
       if (bzf) {
         if (ReadTestBlobs(bzf,3)) {
           rc = true;
@@ -220,17 +220,17 @@ static bool BZ2IOTest()
         BZ2_bzclose(bzf);
       }
       else {
-        cerr << "gzopen(\"/tmp/DWMBZ2IOTest.gz\",\"rb\") failed: "
+        cerr << "gzopen(\"/tmp/DWMBZ2IOTest.bz2\",\"rb\") failed: "
              << strerror(errno) << endl;
       }
     }
     else {
       BZ2_bzclose(bzf);
     }
-    std::remove("/tmp/DWMBZ2IOTest.gz");
+    std::remove("/tmp/DWMBZ2IOTest.bz2");
   }
   else {
-    cerr << "gzopen(\"/tmp/DWMBZ2IOTest.gz\",\"wb\")"
+    cerr << "gzopen(\"/tmp/DWMBZ2IOTest.bz2\",\"wb\")"
          << " failed: " << strerror(errno) << endl;
   }
   
@@ -244,7 +244,7 @@ static bool BZ2IOTest()
 static bool MapBZ2IOTest()
 {
   bool  rc = false;
-  string  fn("/tmp/DWMMapBZ2IOTest.gz");
+  string  fn("/tmp/DWMMapBZ2IOTest.bz2");
   
   map<Ipv4Address,Ipv4Prefix>  m1;
   m1[Ipv4Address("192.168.168.1")] = Ipv4Prefix("192.168.168/24");
@@ -289,7 +289,7 @@ static bool MapBZ2IOTest()
 static bool VectorBZ2IOTest()
 {
   bool  rc = false;
-  string  fn("/tmp/DWMVectorBZ2IOTest.gz");
+  string  fn("/tmp/DWMVectorBZ2IOTest.bz2");
   vector<Ipv4Prefix>  v1;
   v1.push_back(Ipv4Prefix("192.168.168/24"));
   v1.push_back(Ipv4Prefix("10/8"));
@@ -330,7 +330,7 @@ static bool DequeBZ2IOTest()
 {
   bool  rc = false;
 
-  string  fn("/tmp/DWMDequeBZ2IOTest.gz");
+  string  fn("/tmp/DWMDequeBZ2IOTest.bz2");
   deque<Ipv4Prefix>  d1;
   d1.push_back(Ipv4Prefix("192.168.168/24"));
   d1.push_back(Ipv4Prefix("10/8"));
@@ -371,7 +371,7 @@ static bool ListBZ2IOTest()
 {
   bool  rc = false;
 
-  string  fn("/tmp/DWMDequeBZ2IOTest.gz");
+  string  fn("/tmp/DWMDequeBZ2IOTest.bz2");
   list<Ipv4Prefix>  l1;
   l1.push_back(Ipv4Prefix("192.168.168/24"));
   l1.push_back(Ipv4Prefix("10/8"));
@@ -412,7 +412,7 @@ static bool SetBZ2IOTest()
 {
   bool  rc = false;
 
-  string  fn("/tmp/DWMDequeBZ2IOTest.gz");
+  string  fn("/tmp/DWMDequeBZ2IOTest.bz2");
   set<Ipv4Prefix>  s1;
   s1.insert(Ipv4Prefix("192.168.168/24"));
   s1.insert(Ipv4Prefix("10/8"));
@@ -468,6 +468,45 @@ void TestNullBZ2File()
   return;
 }
 
+//----------------------------------------------------------------------------
+//!  
+//----------------------------------------------------------------------------
+void VariantBZ2IOTest()
+{
+  string   fn("./VariantBZ2IOTest.bz2");
+  BZFILE  *bzf = BZ2_bzopen(fn.c_str(), "wb");
+  if (UnitAssert(bzf)) {
+    std::variant<std::monostate,int,std::string>  v1;
+    if (UnitAssert(BZ2IO::BZWrite(bzf, v1) >= 0)) {
+      v1 = 42;
+      if (UnitAssert(BZ2IO::BZWrite(bzf, v1) >= 0)) {
+        v1 = "hello";
+        UnitAssert(BZ2IO::BZWrite(bzf, v1));
+      }
+    }
+    BZ2_bzclose(bzf);
+  }
+
+  bzf = BZ2_bzopen(fn.c_str(), "rb");
+  if (UnitAssert(bzf)) {
+    std::variant<std::monostate,int,std::string>  v2;
+    if (UnitAssert(BZ2IO::BZRead(bzf, v2) >= 0)) {
+      if (UnitAssert(v2.index() == 0)) {
+        if (UnitAssert(BZ2IO::BZRead(bzf, v2) >= 0)) {
+          UnitAssert(v2.index() == 1);
+          UnitAssert(42 == std::get<1>(v2));
+          if (UnitAssert(BZ2IO::BZRead(bzf, v2) >= 0)) {
+            UnitAssert(v2.index() == 2);
+            UnitAssert(string("hello") == std::get<2>(v2));
+          }
+        }
+      }
+    }
+    BZ2_bzclose(bzf);
+  }
+  std::remove(fn.c_str());
+}
+
 //----------------------------------------------------------------------------
 //!  
 //----------------------------------------------------------------------------
@@ -481,7 +520,8 @@ int main(int argc, char *argv[])
   ListBZ2IOTest();
   SetBZ2IOTest();
   TestNullBZ2File();
-
+  VariantBZ2IOTest();
+  
   int  rc = 1;
   if (Assertions::Total().Failed()) {
     Assertions::Print(cerr, true);
