@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestGroup.cc 9015 $
-// @(#) $Id: TestGroup.cc 9015 2017-04-11 16:50:27Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestGroup.cc 11086 $
+// @(#) $Id: TestGroup.cc 11086 2020-09-06 06:17:20Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2016
 //  All rights reserved.
@@ -50,7 +50,7 @@ extern "C" {
 #include "DwmSvnTag.hh"
 #include "DwmUnitAssert.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestGroup.cc 9015 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestGroup.cc 11086 $");
 
 using namespace std;
 
@@ -72,6 +72,11 @@ int main(int argc, char *argv[])
   Dwm::Password  syslogpwd("syslog");
   auto  gmit = std::find(adm.Members().begin(), adm.Members().end(),
                          syslogpwd.UserName());
+  if (gmit == adm.Members().end()) {
+    Dwm::Password  pipwd("pi");
+    gmit = std::find(adm.Members().begin(), adm.Members().end(),
+                     pipwd.UserName());
+  }
   UnitAssert(gmit != adm.Members().end());
 #endif  
   
