@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestIODeque.cc 8389 $
-// @(#) $Id: TestIODeque.cc 8389 2016-04-17 04:31:36Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestIODeque.cc 11087 $
+// @(#) $Id: TestIODeque.cc 11087 2020-09-07 09:58:37Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2005-2007, 2016
 //  All rights reserved.
@@ -51,12 +51,14 @@ extern "C" {
 #include <deque>
 #include <fstream>
 
-#include "DwmIO.hh"
+#include "DwmDescriptorIO.hh"
+#include "DwmFileIO.hh"
+#include "DwmStreamIO.hh"
 #include "DwmGZIO.hh"
 #include "DwmSvnTag.hh"
 #include "DwmUnitAssert.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestIODeque.cc 8389 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestIODeque.cc 11087 $");
 
 using namespace std;
 using namespace Dwm;
@@ -114,7 +116,7 @@ int main(int argc, char *argv[])
   
   ofstream  os(STOREFILE);
   if (os) {
-    if (! IO::Write(os, deque1)) {
+    if (! StreamIO::Write(os, deque1)) {
       cerr << "Failed to write deque1!" << endl;
       exit(1);
     }
@@ -128,7 +130,7 @@ int main(int argc, char *argv[])
   deque<string>  deque2;
   ifstream  is(STOREFILE);
   if (is) {
-    if (! IO::Read(is, deque2)) {
+    if (! StreamIO::Read(is, deque2)) {
       cerr << "Failed to read deque2!" << endl;
       exit(1);
     }
@@ -147,7 +149,7 @@ int main(int argc, char *argv[])
   deque<string>  deque3 = deque1;
   int  fd = open(STOREFILE,O_WRONLY|O_CREAT,0666);
   if (fd >= 0) {
-    if (! IO::Write(fd, deque3)) {
+    if (! DescriptorIO::Write(fd, deque3)) {
       cerr << "Failed to write deque3 to descriptor!" << endl;
       exit(1);
     }
@@ -160,7 +162,7 @@ int main(int argc, char *argv[])
   
   fd = open(STOREFILE,O_RDONLY);
   if (fd >= 0) {
-    if (! IO::Read(fd, deque2)) {
+    if (! DescriptorIO::Read(fd, deque2)) {
       cerr << "Failed to read deque2 from descriptor!" << endl;
       exit(1);
     }
@@ -177,7 +179,7 @@ int main(int argc, char *argv[])
 
   FILE  *f = fopen(STOREFILE,"w");
   if (f) {
-    if (! IO::Write(f, deque1)) {
+    if (! FileIO::Write(f, deque1)) {
       cerr << "Failed to write deque1 to FILE!" << endl;
       exit(1);
     }
@@ -191,7 +193,7 @@ int main(int argc, char *argv[])
   deque3.clear();
   f = fopen(STOREFILE,"r");
   if (f) {
-    if (! IO::Read(f, deque3)) {
+    if (! FileIO::Read(f, deque3)) {
       cerr << "Failed to read deque3 to FILE!" << endl;
       exit(1);
     }
