@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestIOList.cc 8389 $
-// @(#) $Id: TestIOList.cc 8389 2016-04-17 04:31:36Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestIOList.cc 11087 $
+// @(#) $Id: TestIOList.cc 11087 2020-09-07 09:58:37Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2005-2007, 2016
 //  All rights reserved.
@@ -36,7 +36,7 @@
 
 //---------------------------------------------------------------------------
 //!  \file TestIOList.cc
-//!  \brief Unit tests for Dwm::IO with lists
+//!  \brief Unit tests for I/O with lists
 //---------------------------------------------------------------------------
 
 extern "C" {
@@ -49,11 +49,13 @@ extern "C" {
 #include <fstream>
 #include <list>
 
-#include "DwmIO.hh"
+#include "DwmDescriptorIO.hh"
+#include "DwmFileIO.hh"
+#include "DwmStreamIO.hh"
 #include "DwmSvnTag.hh"
 #include "DwmUnitAssert.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestIOList.cc 8389 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestIOList.cc 11087 $");
 
 using namespace std;
 using namespace Dwm;
@@ -74,7 +76,7 @@ int main(int argc, char *argv[])
   
   ofstream  os(STOREFILE);
   if (os) {
-    if (! IO::Write(os, list1)) {
+    if (! StreamIO::Write(os, list1)) {
       cerr << "Failed to write list1!" << endl;
       exit(1);
     }
@@ -88,7 +90,7 @@ int main(int argc, char *argv[])
   list<std::string>  list2;
   ifstream  is(STOREFILE);
   if (is) {
-    if (! IO::Read(is, list2)) {
+    if (! StreamIO::Read(is, list2)) {
       cerr << "Failed to read list2!" << endl;
       exit(1);
     }
@@ -107,7 +109,7 @@ int main(int argc, char *argv[])
   list<std::string>  list3 = list1;
   int  fd = open(STOREFILE,O_WRONLY|O_CREAT,0666);
   if (fd >= 0) {
-    if (! IO::Write(fd, list3)) {
+    if (! DescriptorIO::Write(fd, list3)) {
       cerr << "Failed to write list3 to descriptor!" << endl;
       exit(1);
     }
@@ -120,7 +122,7 @@ int main(int argc, char *argv[])
   
   fd = open(STOREFILE,O_RDONLY);
   if (fd >= 0) {
-    if (! IO::Read(fd, list2)) {
+    if (! DescriptorIO::Read(fd, list2)) {
       cerr << "Failed to read list2 from descriptor!" << endl;
       exit(1);
     }
@@ -137,7 +139,7 @@ int main(int argc, char *argv[])
 
   FILE  *f = fopen(STOREFILE,"w");
   if (f) {
-    if (! IO::Write(f, list1)) {
+    if (! FileIO::Write(f, list1)) {
       cerr << "Failed to write list1 to FILE!" << endl;
       exit(1);
     }
@@ -151,7 +153,7 @@ int main(int argc, char *argv[])
   list3.clear();
   f = fopen(STOREFILE,"r");
   if (f) {
-    if (! IO::Read(f, list3)) {
+    if (! FileIO::Read(f, list3)) {
       cerr << "Failed to read list3 to FILE!" << endl;
       exit(1);
     }
