@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestIOMap.cc 9011 $
-// @(#) $Id: TestIOMap.cc 9011 2017-04-11 04:36:51Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestIOMap.cc 11087 $
+// @(#) $Id: TestIOMap.cc 11087 2020-09-07 09:58:37Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2005-2007, 2016
 //  All rights reserved.
@@ -36,7 +36,7 @@
 
 //---------------------------------------------------------------------------
 //!  \file TestIOMap.cc
-//!  \brief Unit tests for Dwm::IO with maps
+//!  \brief Unit tests for I/O with maps
 //---------------------------------------------------------------------------
 
 extern "C" {
@@ -50,12 +50,14 @@ extern "C" {
 #include <map>
 #include <vector>
 
-#include "DwmIO.hh"
+#include "DwmDescriptorIO.hh"
+#include "DwmFileIO.hh"
+#include "DwmStreamIO.hh"
 #include "DwmGZIO.hh"
 #include "DwmSvnTag.hh"
 #include "DwmUnitAssert.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestIOMap.cc 9011 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestIOMap.cc 11087 $");
 
 using namespace std;
 using namespace Dwm;
@@ -81,7 +83,7 @@ int main(int argc, char *argv[])
   
   ofstream  os(STOREFILE);
   if (os) {
-    if (! IO::Write(os, map1)) {
+    if (! StreamIO::Write(os, map1)) {
       cerr << "Failed to write map1!" << endl;
       exit(1);
     }
@@ -95,7 +97,7 @@ int main(int argc, char *argv[])
   map<uint32_t,vector<std::string> >  map2;
   ifstream  is(STOREFILE);
   if (is) {
-    if (! IO::Read(is, map2)) {
+    if (! StreamIO::Read(is, map2)) {
       cerr << "Failed to read map2!" << endl;
       exit(1);
     }
@@ -115,7 +117,7 @@ int main(int argc, char *argv[])
   map<uint32_t,vector<string> >  map3 = map1;
   int  fd = open(STOREFILE,O_WRONLY|O_CREAT,0666);
   if (fd >= 0) {
-    if (! IO::Write(fd, map3)) {
+    if (! DescriptorIO::Write(fd, map3)) {
       cerr << "Failed to write map3 to descriptor!" << endl;
       exit(1);
     }
@@ -128,7 +130,7 @@ int main(int argc, char *argv[])
   
   fd = open(STOREFILE,O_RDONLY);
   if (fd >= 0) {
-    if (! IO::Read(fd, map2)) {
+    if (! DescriptorIO::Read(fd, map2)) {
       cerr << "Failed to read map2 from descriptor!" << endl;
       exit(1);
     }
@@ -146,7 +148,7 @@ int main(int argc, char *argv[])
 
   FILE  *f = fopen(STOREFILE,"w");
   if (f) {
-    if (! IO::Write(f, map1)) {
+    if (! FileIO::Write(f, map1)) {
       cerr << "Failed to write map1 to FILE!" << endl;
       exit(1);
     }
@@ -160,7 +162,7 @@ int main(int argc, char *argv[])
   map3.clear();
   f = fopen(STOREFILE,"r");
   if (f) {
-    if (! IO::Read(f, map3)) {
+    if (! FileIO::Read(f, map3)) {
       cerr << "Failed to read map3 from FILE!" << endl;
       exit(1);
     }
