@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestIOMultiMap.cc 8389 $
-// @(#) $Id: TestIOMultiMap.cc 8389 2016-04-17 04:31:36Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestIOMultiMap.cc 11087 $
+// @(#) $Id: TestIOMultiMap.cc 11087 2020-09-07 09:58:37Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2005-2007, 2016
 //  All rights reserved.
@@ -49,11 +49,13 @@ extern "C" {
 #include <fstream>
 #include <map>
 
-#include "DwmIO.hh"
+#include "DwmDescriptorIO.hh"
+#include "DwmFileIO.hh"
+#include "DwmStreamIO.hh"
 #include "DwmSvnTag.hh"
 #include "DwmUnitAssert.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestIOMultiMap.cc 8389 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestIOMultiMap.cc 11087 $");
 
 using namespace std;
 using namespace Dwm;
@@ -73,7 +75,7 @@ int main(int argc, char *argv[])
   
   ofstream  os(STOREFILE);
   if (os) {
-    if (! IO::Write(os, multimap1)) {
+    if (! StreamIO::Write(os, multimap1)) {
       cerr << "Failed to write multimap1!" << endl;
       exit(1);
     }
@@ -88,7 +90,7 @@ int main(int argc, char *argv[])
   multimap<uint32_t,std::string>  multimap2;
   ifstream  is(STOREFILE);
   if (is) {
-    if (! IO::Read(is, multimap2)) {
+    if (! StreamIO::Read(is, multimap2)) {
       cerr << "Failed to read multimap2!" << endl;
       exit(1);
     }
@@ -108,7 +110,7 @@ int main(int argc, char *argv[])
   multimap<uint32_t,std::string>  multimap3 = multimap1;
   int  fd = open(STOREFILE,O_WRONLY|O_CREAT,0666);
   if (fd >= 0) {
-    if (! IO::Write(fd, multimap3)) {
+    if (! DescriptorIO::Write(fd, multimap3)) {
       cerr << "Failed to write multimap3 to descriptor!" << endl;
       exit(1);
     }
@@ -122,7 +124,7 @@ int main(int argc, char *argv[])
   
   fd = open(STOREFILE,O_RDONLY);
   if (fd >= 0) {
-    if (! IO::Read(fd, multimap2)) {
+    if (! DescriptorIO::Read(fd, multimap2)) {
       cerr << "Failed to read multimap2 from descriptor!" << endl;
       exit(1);
     }
@@ -140,7 +142,7 @@ int main(int argc, char *argv[])
 
   FILE  *f = fopen(STOREFILE,"w");
   if (f) {
-    if (! IO::Write(f, multimap1)) {
+    if (! FileIO::Write(f, multimap1)) {
       cerr << "Failed to write multimap1 to FILE!" << endl;
       exit(1);
     }
@@ -155,7 +157,7 @@ int main(int argc, char *argv[])
   multimap3.clear();
   f = fopen(STOREFILE,"r");
   if (f) {
-    if (! IO::Read(f, multimap3)) {
+    if (! FileIO::Read(f, multimap3)) {
       cerr << "Failed to read multimap3 to FILE!" << endl;
       exit(1);
     }
