@@ -1,8 +1,8 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestIOMultiSet.cc 8389 $
-// @(#) $Id: TestIOMultiSet.cc 8389 2016-04-17 04:31:36Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestIOMultiSet.cc 11087 $
+// @(#) $Id: TestIOMultiSet.cc 11087 2020-09-07 09:58:37Z dwm $
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 2005-2007, 2016
+//  Copyright (c) Daniel W. McRobb 2005-2007, 2016, 2020
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -36,6 +36,7 @@
 
 //---------------------------------------------------------------------------
 //!  \file TestIOMultiSet.cc
+//!  \author Daniel W. McRobb
 //!  \brief Unit tests for Dwm::IO with multisets
 //---------------------------------------------------------------------------
 
@@ -49,11 +50,13 @@ extern "C" {
 #include <fstream>
 #include <set>
 
-#include "DwmIO.hh"
+#include "DwmDescriptorIO.hh"
+#include "DwmFileIO.hh"
+#include "DwmStreamIO.hh"
 #include "DwmSvnTag.hh"
 #include "DwmUnitAssert.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestIOMultiSet.cc 8389 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestIOMultiSet.cc 11087 $");
 
 using namespace std;
 using namespace Dwm;
@@ -70,11 +73,8 @@ int main(int argc, char *argv[])
   multiset1.insert("3");
   
   ofstream  os("/tmp/DwmTestIOMultiSet.store");
-  if (os) {
-    if (! IO::Write(os, multiset1)) {
-      cerr << "Failed to write multiset1!" << endl;
-      exit(1);
-    }
+  if (UnitAssert(os)) {
+    UnitAssert(StreamIO::Write(os, multiset1));
     os.close();
   }
   else {
@@ -84,14 +84,10 @@ int main(int argc, char *argv[])
   
   multiset<std::string>  multiset2;
   ifstream  is("/tmp/DwmTestIOMultiSet.store");
-  if (is) {
-    if (! IO::Read(is, multiset2)) {
-      cerr << "Failed to read multiset2!" << endl;
-      exit(1);
-    }
+  if (UnitAssert(is)) {
+    UnitAssert(StreamIO::Read(is, multiset2));
     is.close();
     std::remove("/tmp/DwmTestIOMultiSet.store");
-    
     UnitAssert(multiset2 == multiset1);
     UnitAssert(multiset1.size() == 3);
     
@@ -103,11 +99,8 @@ int main(int argc, char *argv[])
 
   multiset<std::string>  multiset3 = multiset1;
   int  fd = open("/tmp/DwmTestIOMultiSet.store",O_WRONLY|O_CREAT,0666);
-  if (fd >= 0) {
-    if (! IO::Write(fd, multiset3)) {
-      cerr << "Failed to write multiset3 to descriptor!" << endl;
-      exit(1);
-    }
+  if (UnitAssert(fd >= 0)) {
+    UnitAssert(DescriptorIO::Write(fd, multiset3));
     close(fd);
   }
   else {
@@ -116,11 +109,8 @@ int main(int argc, char *argv[])
   }
   
   fd = open("/tmp/DwmTestIOMultiSet.store",O_RDONLY);
-  if (fd >= 0) {
-    if (! IO::Read(fd, multiset2)) {
-      cerr << "Failed to read multiset2 from descriptor!" << endl;
-      exit(1);
-    }
+  if (UnitAssert(fd >= 0)) {
+    UnitAssert(DescriptorIO::Read(fd, multiset2));
     close(fd);
     UnitAssert (multiset2 == multiset3);
     UnitAssert(multiset2.size() == 3);
@@ -133,11 +123,8 @@ int main(int argc, char *argv[])
   std::remove("/tmp/DwmTestIOMultiSet.store");
 
   FILE  *f = fopen("/tmp/DwmTestIOMultiSet.store","w");
-  if (f) {
-    if (! IO::Write(f, multiset1)) {
-      cerr << "Failed to write multiset1 to FILE!" << endl;
-      exit(1);
-    }
+  if (UnitAssert(f)) {
+    UnitAssert(FileIO::Write(f, multiset1));
     fclose(f);
   }
   else {
@@ -147,11 +134,8 @@ int main(int argc, char *argv[])
   
   multiset3.clear();
   f = fopen("/tmp/DwmTestIOMultiSet.store","r");
-  if (f) {
-    if (! IO::Read(f, multiset3)) {
-      cerr << "Failed to read multiset3 to FILE!" << endl;
-      exit(1);
-    }
+  if (UnitAssert(f)) {
+    UnitAssert(FileIO::Read(f, multiset3));
     fclose(f);
     UnitAssert (multiset2 == multiset3);
     UnitAssert(multiset3.size() == 3);
