@@ -1,8 +1,8 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestIOSet.cc 8389 $
-// @(#) $Id: TestIOSet.cc 8389 2016-04-17 04:31:36Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestIOSet.cc 11087 $
+// @(#) $Id: TestIOSet.cc 11087 2020-09-07 09:58:37Z dwm $
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 2005-2007, 2016
+//  Copyright (c) Daniel W. McRobb 2005-2007, 2016, 2020
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -36,6 +36,7 @@
 
 //---------------------------------------------------------------------------
 //!  \file TestIOSet.cc
+//!  \author Daniel W. McRobb
 //!  \brief Unit tests for Dwm::IO with sets
 //---------------------------------------------------------------------------
 
@@ -48,11 +49,13 @@ extern "C" {
 #include <cstdio>
 #include <fstream>
 
-#include "DwmIO.hh"
+#include "DwmDescriptorIO.hh"
+#include "DwmFileIO.hh"
+#include "DwmStreamIO.hh"
 #include "DwmSvnTag.hh"
 #include "DwmUnitAssert.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestIOSet.cc 8389 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestIOSet.cc 11087 $");
 
 using namespace std;
 using namespace Dwm;
@@ -69,11 +72,8 @@ int main(int argc, char *argv[])
   set1.insert("3");
   
   ofstream  os("/tmp/DwmTestIOSet.store");
-  if (os) {
-    if (! IO::Write(os, set1)) {
-      cerr << "Failed to write set1!" << endl;
-      exit(1);
-    }
+  if (UnitAssert(os)) {
+    UnitAssert(StreamIO::Write(os, set1));
     os.close();
   }
   else {
@@ -83,17 +83,12 @@ int main(int argc, char *argv[])
   
   set<std::string>  set2;
   ifstream  is("/tmp/DwmTestIOSet.store");
-  if (is) {
-    if (! IO::Read(is, set2)) {
-      cerr << "Failed to read set2!" << endl;
-      exit(1);
-    }
+  if (UnitAssert(is)) {
+    UnitAssert(StreamIO::Read(is, set2));
     is.close();
     std::remove("/tmp/DwmTestIOSet.store");
-    
     UnitAssert(set2 == set1);
     UnitAssert(set1.size() == 3);
-    
   }
   else {
     cerr << "Failed to open '/tmp/DwmTestIOSet.store' for reading!" << endl;
@@ -102,11 +97,8 @@ int main(int argc, char *argv[])
 
   set<std::string>  set3 = set1;
   int  fd = open("/tmp/DwmTestIOSet.store",O_WRONLY|O_CREAT,0666);
-  if (fd >= 0) {
-    if (! IO::Write(fd, set3)) {
-      cerr << "Failed to write set3 to descriptor!" << endl;
-      exit(1);
-    }
+  if (UnitAssert(fd >= 0)) {
+    UnitAssert (DescriptorIO::Write(fd, set3));
     close(fd);
   }
   else {
@@ -115,11 +107,8 @@ int main(int argc, char *argv[])
   }
   
   fd = open("/tmp/DwmTestIOSet.store",O_RDONLY);
-  if (fd >= 0) {
-    if (! IO::Read(fd, set2)) {
-      cerr << "Failed to read set2 from descriptor!" << endl;
-      exit(1);
-    }
+  if (UnitAssert(fd >= 0)) {
+    UnitAssert(DescriptorIO::Read(fd, set2));
     close(fd);
     UnitAssert (set2 == set3);
     UnitAssert(set2.size() == 3);
@@ -132,11 +121,8 @@ int main(int argc, char *argv[])
   std::remove("/tmp/DwmTestIOSet.store");
 
   FILE  *f = fopen("/tmp/DwmTestIOSet.store","w");
-  if (f) {
-    if (! IO::Write(f, set1)) {
-      cerr << "Failed to write set1 to FILE!" << endl;
-      exit(1);
-    }
+  if (UnitAssert(f)) {
+    UnitAssert(FileIO::Write(f, set1));
     fclose(f);
   }
   else {
@@ -146,11 +132,8 @@ int main(int argc, char *argv[])
   
   set3.clear();
   f = fopen("/tmp/DwmTestIOSet.store","r");
-  if (f) {
-    if (! IO::Read(f, set3)) {
-      cerr << "Failed to read set3 to FILE!" << endl;
-      exit(1);
-    }
+  if (UnitAssert(f)) {
+    UnitAssert(FileIO::Read(f, set3));
     fclose(f);
     UnitAssert (set2 == set3);
     UnitAssert(set3.size() == 3);
