@@ -1,8 +1,8 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestIOVector.cc 8389 $
-// @(#) $Id: TestIOVector.cc 8389 2016-04-17 04:31:36Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestIOVector.cc 11087 $
+// @(#) $Id: TestIOVector.cc 11087 2020-09-07 09:58:37Z dwm $
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 2005-2007, 2016
+//  Copyright (c) Daniel W. McRobb 2005-2007, 2016, 2020
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -36,6 +36,7 @@
 
 //---------------------------------------------------------------------------
 //!  \file TestIOVector.cc
+//!  \author Daniel W. McRobb
 //!  \brief Unit tests for Dwm::IO with vectors
 //---------------------------------------------------------------------------
 
@@ -49,11 +50,13 @@ extern "C" {
 #include <fstream>
 #include <vector>
 
-#include "DwmIO.hh"
+#include "DwmDescriptorIO.hh"
+#include "DwmFileIO.hh"
+#include "DwmStreamIO.hh"
 #include "DwmSvnTag.hh"
 #include "DwmUnitAssert.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestIOVector.cc 8389 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestIOVector.cc 11087 $");
 
 using namespace std;
 using namespace Dwm;
@@ -70,11 +73,8 @@ int main(int argc, char *argv[])
   vector1.push_back("3");
   
   ofstream  os("/tmp/DwmTestIOVector.store");
-  if (os) {
-    if (! IO::Write(os, vector1)) {
-      cerr << "Failed to write vector1!" << endl;
-      exit(1);
-    }
+  if (UnitAssert(os)) {
+    UnitAssert(StreamIO::Write(os, vector1));
     os.close();
   }
   else {
@@ -84,17 +84,12 @@ int main(int argc, char *argv[])
   
   vector<std::string>  vector2;
   ifstream  is("/tmp/DwmTestIOVector.store");
-  if (is) {
-    if (! IO::Read(is, vector2)) {
-      cerr << "Failed to read vector2!" << endl;
-      exit(1);
-    }
+  if (UnitAssert(is)) {
+    UnitAssert(StreamIO::Read(is, vector2));
     is.close();
     std::remove("/tmp/DwmTestIOVector.store");
-    
     UnitAssert(vector2 == vector1);
     UnitAssert(vector1.size() == 3);
-    
   }
   else {
     cerr << "Failed to open '/tmp/DwmTestIOVector.store' for reading!" << endl;
@@ -103,11 +98,8 @@ int main(int argc, char *argv[])
 
   vector<std::string>  vector3 = vector1;
   int  fd = open("/tmp/DwmTestIOVector.store",O_WRONLY|O_CREAT,0666);
-  if (fd >= 0) {
-    if (! IO::Write(fd, vector3)) {
-      cerr << "Failed to write vector3 to descriptor!" << endl;
-      exit(1);
-    }
+  if (UnitAssert(fd >= 0)) {
+    UnitAssert(DescriptorIO::Write(fd, vector3));
     close(fd);
   }
   else {
@@ -116,11 +108,8 @@ int main(int argc, char *argv[])
   }
   
   fd = open("/tmp/DwmTestIOVector.store",O_RDONLY);
-  if (fd >= 0) {
-    if (! IO::Read(fd, vector2)) {
-      cerr << "Failed to read vector2 from descriptor!" << endl;
-      exit(1);
-    }
+  if (UnitAssert(fd >= 0)) {
+    UnitAssert(DescriptorIO::Read(fd, vector2));
     close(fd);
     UnitAssert (vector2 == vector3);
     UnitAssert(vector2.size() == 3);
@@ -133,11 +122,8 @@ int main(int argc, char *argv[])
   std::remove("/tmp/DwmTestIOVector.store");
 
   FILE  *f = fopen("/tmp/DwmTestIOVector.store","w");
-  if (f) {
-    if (! IO::Write(f, vector1)) {
-      cerr << "Failed to write vector1 to FILE!" << endl;
-      exit(1);
-    }
+  if (UnitAssert(f)) {
+    UnitAssert(FileIO::Write(f, vector1));
     fclose(f);
   }
   else {
@@ -147,11 +133,8 @@ int main(int argc, char *argv[])
   
   vector3.clear();
   f = fopen("/tmp/DwmTestIOVector.store","r");
-  if (f) {
-    if (! IO::Read(f, vector3)) {
-      cerr << "Failed to read vector3 to FILE!" << endl;
-      exit(1);
-    }
+  if (UnitAssert(f)) {
+    UnitAssert(FileIO::Read(f, vector3));
     fclose(f);
     UnitAssert (vector2 == vector3);
     UnitAssert(vector3.size() == 3);
