@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestProcessTable.cc 9019 $
-// @(#) $Id: TestProcessTable.cc 9019 2017-04-11 20:27:35Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestProcessTable.cc 11087 $
+// @(#) $Id: TestProcessTable.cc 11087 2020-09-07 09:58:37Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2006-2007
 //  All rights reserved.
@@ -51,12 +51,12 @@ extern "C" {
 
 #include "DwmSvnTag.hh"
 #include "DwmGZIO.hh"
-#include "DwmIO.hh"
+#include "DwmStreamIO.hh"
 #include "DwmProcessTable.hh"
 #include "DwmEngFormat.hh"
 #include "DwmUnitAssert.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestProcessTable.cc 9019 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestProcessTable.cc 11087 $");
 
 using namespace std;
 using namespace Dwm;
@@ -71,12 +71,12 @@ static void TestProcessTableIO(ProcessTable & processTable)
   
   ofstream  os(filename.str().c_str());
   if (os) {
-    UnitAssert(IO::Write(os, processTable));
+    UnitAssert(StreamIO::Write(os, processTable));
     os.close();
     ifstream  is(filename.str().c_str());
     if (is) {
       ProcessTable  processTable2;
-      UnitAssert(IO::Read(is, processTable2));
+      UnitAssert(StreamIO::Read(is, processTable2));
       UnitAssert(processTable == processTable2);
       is.close();
     }
