@@ -1,8 +1,8 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestTupleIO.cc 9010 $
-// @(#) $Id: TestTupleIO.cc 9010 2017-04-11 04:28:05Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestTupleIO.cc 11087 $
+// @(#) $Id: TestTupleIO.cc 11087 2020-09-07 09:58:37Z dwm $
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 2007, 2016
+//  Copyright (c) Daniel W. McRobb 2007, 2016, 2020
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -36,6 +36,7 @@
 
 //---------------------------------------------------------------------------
 //!  \file TestTupleIO.cc
+//!  \author Daniel W. McRobb
 //!  \brief tuple I/O tests
 //---------------------------------------------------------------------------
 
@@ -53,13 +54,16 @@ extern "C" {
 
 #include "DwmBZ2IO.hh"
 #include "DwmGZIO.hh"
-#include "DwmIO.hh"
+#include "DwmDescriptorIO.hh"
+#include "DwmFileIO.hh"
+#include "DwmStreamIO.hh"
+#include "DwmIOUtils.hh"
 #include "DwmPortability.hh"
 #include "DwmSvnTag.hh"
 #include "DwmTimeValue.hh"
 #include "DwmUnitAssert.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestTupleIO.cc 9010 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestTupleIO.cc 11087 $");
 
 using namespace std;
 using namespace Dwm;
@@ -75,11 +79,11 @@ template <typename TupleType>
 static void TestTupleStreamIO(const TupleType & t)
 {
   ofstream  os(TUPLE_TEST_FILE);
-  UnitAssert(IO::Write(os, t));
+  UnitAssert(StreamIO::Write(os, t));
   os.close();
   TupleType  u;
   ifstream  is(TUPLE_TEST_FILE);
-  UnitAssert(IO::Read(is, u));
+  UnitAssert(StreamIO::Read(is, u));
   is.close();
   UnitAssert(u == t);
   std::remove(TUPLE_TEST_FILE);
@@ -94,12 +98,12 @@ static void TestTupleDescriptorIO(const TupleType & t)
 {
   int  fd = open(TUPLE_TEST_FILE, O_WRONLY|O_CREAT, 0666);
   if (UnitAssert(fd >= 0)) {
-    UnitAssert(IO::Write(fd, t) == IO::StreamedLength(t));
+    UnitAssert(DescriptorIO::Write(fd, t) == IOUtils::StreamedLength(t));
     close(fd);
     fd = open(TUPLE_TEST_FILE, O_RDONLY);
     if (UnitAssert(fd >= 0)) {
       TupleType  u;
-      UnitAssert(IO::Read(fd, u));
+      UnitAssert(DescriptorIO::Read(fd, u));
       close(fd);
       UnitAssert(u == t);
     }
@@ -116,12 +120,12 @@ static void TestTupleFileIO(const TupleType & t)
 {
   FILE  *f = fopen(TUPLE_TEST_FILE, "wb");
   if (UnitAssert(f)) {
-    UnitAssert(IO::Write(f, t));
+    UnitAssert(FileIO::Write(f, t));
     fclose(f);
     f = fopen(TUPLE_TEST_FILE, "rb");
     if (UnitAssert(f)) {
       TupleType  u;
-      UnitAssert(IO::Read(f, u));
+      UnitAssert(FileIO::Read(f, u));
       fclose(f);
       UnitAssert(u == t);
     }
@@ -193,47 +197,47 @@ static void TestSingleTuples()
 {
   tuple<int,string>
     t2(0, "dwm");
-  UnitAssert(IO::StreamedLength(t2) == 11);
+  UnitAssert(IOUtils::StreamedLength(t2) == 11);
   TestTupleIO(t2);
 
   tuple<int,string,string>
     t3(0, "dwm", "mwd");
-  UnitAssert(IO::StreamedLength(t3) == 18);
+  UnitAssert(IOUtils::StreamedLength(t3) == 18);
   TestTupleIO(t3);
 
   tuple<int,string,int,string>
     t4(0, "dwm", 2, "wmd");
-  UnitAssert(IO::StreamedLength(t4) == 22);
+  UnitAssert(IOUtils::StreamedLength(t4) == 22);
   TestTupleIO(t4);
 
   tuple<int,string,int,string,int>
     t5(1, "alpha", 2, "beta", 3);
-  UnitAssert(IO::StreamedLength(t5) == 29);
+  UnitAssert(IOUtils::StreamedLength(t5) == 29);
   TestTupleIO(t5);
 
   tuple<int,string,int,string,int,string>
     t6(1, "alpha", 2, "beta", 3, "gamma");
-  UnitAssert(IO::StreamedLength(t6) == 38);
+  UnitAssert(IOUtils::StreamedLength(t6) == 38);
   TestTupleIO(t6);
 
   tuple<int,string,int,string,int,string,int>
     t7(1, "alpha", 2, "beta", 3, "gamma", 4);
-  UnitAssert(IO::StreamedLength(t7) == 42);
+  UnitAssert(IOUtils::StreamedLength(t7) == 42);
   TestTupleIO(t7);
 
   tuple<int,string,int,string,int,string,int,string>
     t8(1, "alpha", 2, "beta", 3, "gamma", 4, "delta");
-  UnitAssert(IO::StreamedLength(t8) == 51);
+  UnitAssert(IOUtils::StreamedLength(t8) == 51);
   TestTupleIO(t8);
 
   tuple<int,string,int,string,int,string,int,string,int>
     t9(1, "alpha", 2, "beta", 3, "gamma", 4, "delta", 5);
-  UnitAssert(IO::StreamedLength(t9) == 55);
+  UnitAssert(IOUtils::StreamedLength(t9) == 55);
   TestTupleIO(t9);
 
   tuple<int,string,int,string,int,string,int,string,int,string>
     t10(1, "alpha", 2, "beta", 3, "gamma", 4, "delta", 5, "epsilon");
-  UnitAssert(IO::StreamedLength(t10) == 66);
+  UnitAssert(IOUtils::StreamedLength(t10) == 66);
   
   TestTupleIO(t10);
 
