@@ -1,8 +1,8 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestUnorderedMultimapIO.cc 8478 $
-// @(#) $Id: TestUnorderedMultimapIO.cc 8478 2016-05-07 03:01:47Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestUnorderedMultimapIO.cc 11087 $
+// @(#) $Id: TestUnorderedMultimapIO.cc 11087 2020-09-07 09:58:37Z dwm $
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 2005-2007
+//  Copyright (c) Daniel W. McRobb 2005-2007, 2020
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -36,6 +36,7 @@
 
 //---------------------------------------------------------------------------
 //!  \file TestUnorderedMultimapIO.cc
+//!  \author Daniel W. McRobb
 //!  \brief unordered_multimap I/O unit tests
 //---------------------------------------------------------------------------
 
@@ -55,13 +56,15 @@ extern "C" {
 using std::unordered_multimap;
 
 #include "DwmBZ2IO.hh"
+#include "DwmDescriptorIO.hh"
+#include "DwmFileIO.hh"
 #include "DwmGZIO.hh"
-#include "DwmIO.hh"
+#include "DwmStreamIO.hh"
 #include "DwmOperators.hh"
 #include "DwmSvnTag.hh"
 #include "DwmUnitAssert.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestUnorderedMultimapIO.cc 8478 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestUnorderedMultimapIO.cc 11087 $");
 
 using namespace std;
 using namespace Dwm;
@@ -76,12 +79,12 @@ static void TestStreamIO(const unordered_multimap<K,V> & map1)
 {
   ofstream  os(STOREFILE);
   if (UnitAssert(os)) {
-    UnitAssert(IO::Write(os, map1));
+    UnitAssert(StreamIO::Write(os, map1));
     os.close();
     unordered_multimap<K,V>  map2;
     ifstream  is(STOREFILE);
     if (UnitAssert(is)) {
-      UnitAssert(IO::Read(is, map2));
+      UnitAssert(StreamIO::Read(is, map2));
       is.close();
       UnitAssert(map2 == map1);
     }
@@ -97,12 +100,12 @@ static void TestDescriptorIO(const unordered_multimap<K,V> & map1)
 {
   int  fd = open(STOREFILE,O_WRONLY|O_CREAT,0666);
   if (UnitAssert(fd >= 0)) {
-    UnitAssert(IO::Write(fd, map1));
+    UnitAssert(DescriptorIO::Write(fd, map1));
     close(fd);
     fd = open(STOREFILE,O_RDONLY);
     if (UnitAssert(fd >= 0)) {
       unordered_multimap<K,V>  map2;
-      UnitAssert(IO::Read(fd, map2));
+      UnitAssert(DescriptorIO::Read(fd, map2));
       close(fd);
       UnitAssert(map2 == map1);
     }
@@ -118,12 +121,12 @@ static void TestFileIO(const unordered_multimap<K,V> & map1)
 {
   FILE  *f = fopen(STOREFILE, "w");
   if (UnitAssert(f)) {
-    UnitAssert(IO::Write(f, map1));
+    UnitAssert(FileIO::Write(f, map1));
     fclose(f);
     f = fopen(STOREFILE, "r");
     if (UnitAssert(f)) {
       unordered_multimap<K,V>  map2;
-      UnitAssert(IO::Read(f, map2));
+      UnitAssert(FileIO::Read(f, map2));
       fclose(f);
       UnitAssert (map2 == map1);
     }
