@@ -1,8 +1,8 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestUnorderedMultisetIO.cc 8478 $
-// @(#) $Id: TestUnorderedMultisetIO.cc 8478 2016-05-07 03:01:47Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestUnorderedMultisetIO.cc 11087 $
+// @(#) $Id: TestUnorderedMultisetIO.cc 11087 2020-09-07 09:58:37Z dwm $
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 2005-2007
+//  Copyright (c) Daniel W. McRobb 2005-2007, 2020
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -36,6 +36,7 @@
 
 //---------------------------------------------------------------------------
 //!  \file TestUnorderedMultisetIO.cc
+//!  \author Daniel W. McRobb
 //!  \brief unordered_multiset I/O unit tests
 //---------------------------------------------------------------------------
 
@@ -54,13 +55,15 @@ extern "C" {
 using std::unordered_multiset;
 
 #include "DwmBZ2IO.hh"
+#include "DwmDescriptorIO.hh"
+#include "DwmFileIO.hh"
 #include "DwmGZIO.hh"
-#include "DwmIO.hh"
+#include "DwmStreamIO.hh"
 #include "DwmOperators.hh"
 #include "DwmSvnTag.hh"
 #include "DwmUnitAssert.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestUnorderedMultisetIO.cc 8478 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestUnorderedMultisetIO.cc 11087 $");
 
 using namespace std;
 using namespace Dwm;
@@ -75,12 +78,12 @@ static void TestStreamIO(const unordered_multiset<T> & set1)
 {
   ofstream  os(STOREFILE);
   UnitAssert(os);
-  UnitAssert(IO::Write(os, set1));
+  UnitAssert(StreamIO::Write(os, set1));
   os.close();
   ifstream  is(STOREFILE);
   UnitAssert(is);
   unordered_multiset<T>  set2;
-  UnitAssert(IO::Read(is, set2));
+  UnitAssert(StreamIO::Read(is, set2));
   is.close();
   UnitAssert(set2 == set1);
   unlink(STOREFILE);
@@ -94,12 +97,12 @@ static void TestDescriptorIO(const unordered_multiset<T> & set1)
 {
   int  fd = open(STOREFILE, O_WRONLY|O_CREAT, 0666);
   if (UnitAssert(fd >= 0)) {
-    UnitAssert(IO::Write(fd, set1));
+    UnitAssert(DescriptorIO::Write(fd, set1));
     close(fd);
     fd = open(STOREFILE,O_RDONLY);
     if (UnitAssert(fd >= 0)) {
       unordered_multiset<T>  set2;
-      UnitAssert(IO::Read(fd, set2));
+      UnitAssert(DescriptorIO::Read(fd, set2));
       close(fd);
       UnitAssert(set2 == set1);
     }
@@ -115,12 +118,12 @@ static void TestFileIO(const unordered_multiset<T> & set1)
 {
   FILE  *f = fopen(STOREFILE, "w");
   if (UnitAssert(f)) {
-    UnitAssert(IO::Write(f, set1));
+    UnitAssert(FileIO::Write(f, set1));
     fclose(f);
     f = fopen(STOREFILE,"r");
     if (UnitAssert(f)) {
       unordered_multiset<T>  set2;
-      UnitAssert(IO::Read(f, set2));
+      UnitAssert(FileIO::Read(f, set2));
       fclose(f);
       UnitAssert(set2 == set1);
     }
