@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestVariantIO.cc 10828 $
-// @(#) $Id: TestVariantIO.cc 10828 2020-06-29 01:34:28Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestVariantIO.cc 11087 $
+// @(#) $Id: TestVariantIO.cc 11087 2020-09-07 09:58:37Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2020
 //  All rights reserved.
@@ -37,19 +37,19 @@
 //---------------------------------------------------------------------------
 //!  \file TestVariantIO.cc
 //!  \author Daniel W. McRobb
-//!  \brief NOT YET DOCUMENTED
+//!  \brief std::variant I/O unit tests
 //---------------------------------------------------------------------------
 
 #include <sstream>
 
-#include "DwmIO.hh"
+#include "DwmStreamIO.hh"
 #include "DwmSvnTag.hh"
 #include "DwmUnitAssert.hh"
 
 using namespace std;
 using namespace Dwm;
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.7.1/tests/TestVariantIO.cc 10828 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.0/tests/TestVariantIO.cc 11087 $");
 
 //----------------------------------------------------------------------------
 //!  
@@ -58,21 +58,21 @@ static void TestStreamIO()
 {
   stringstream  ss;
   variant<monostate,int,string>  v1;
-  UnitAssert(IO::Write(ss, v1));
+  UnitAssert(StreamIO::Write(ss, v1));
   v1 = "hello there";
-  UnitAssert(IO::Write(ss, v1));
+  UnitAssert(StreamIO::Write(ss, v1));
   v1 = 42;
-  UnitAssert(IO::Write(ss, v1));
+  UnitAssert(StreamIO::Write(ss, v1));
 
   variant<monostate,int,string>  v2;
-  UnitAssert(IO::Read(ss, v2));
+  UnitAssert(StreamIO::Read(ss, v2));
   UnitAssert(0 == v2.index());
 
-  UnitAssert(IO::Read(ss, v2));
+  UnitAssert(StreamIO::Read(ss, v2));
   UnitAssert(2 == v2.index());
   UnitAssert(string("hello there") == get<2>(v2));
 
-  UnitAssert(IO::Read(ss, v2));
+  UnitAssert(StreamIO::Read(ss, v2));
   UnitAssert(1 == v2.index());
   UnitAssert(get<1>(v2) == 42);
 }
